<?php

$LANG = array(
    'organization' => 'Organisation',
    'name' => 'Navn',
    'website' => 'Hjemmeside',
    'work_phone' => 'Telefon',
    'address' => 'Adresse',
    'address1' => 'Gade',
    'address2' => 'Nummer',
    'city' => 'By',
    'state' => 'Område',
    'postal_code' => 'Postnummer',
    'country_id' => 'Land',
    'contacts' => 'Kontakter',
    'first_name' => 'Fornavn',
    'last_name' => 'Efternavn',
    'phone' => 'Telefon',
    'email' => 'E-mail',
    'additional_info' => 'Ekstra information',
    'payment_terms' => 'Betalingsvilkår',
    'currency_id' => 'Valuta',
    'size_id' => 'Virksomhedens størrelse',
    'industry_id' => 'Sektor',
    'private_notes' => 'Private notater',
    'invoice' => 'Faktura',
    'client' => 'Kunde',
    'invoice_date' => 'Faktureringsdato',
    'due_date' => 'Betalingsfrist',
    'invoice_number' => 'Fakturanummer',
    'invoice_number_short' => 'Faktura nr.: #',
    'po_number' => 'Ordrenummer',
    'po_number_short' => 'Ordre nr.: #',
    'frequency_id' => 'Frekvens',
    'discount' => 'Rabat',
    'taxes' => 'Skatter',
    'tax' => 'Moms',
    'item' => 'Produkttype',
    'description' => 'Beskrivelse',
    'unit_cost' => 'Enhedspris',
    'quantity' => 'Stk.',
    'line_total' => 'Sum',
    'subtotal' => 'Subtotal',
    'paid_to_date' => 'Betalt pr. d.d.',
    'balance_due' => 'Udestående beløb',
    'invoice_design_id' => 'Design',
    'terms' => 'Vilkår',
    'your_invoice' => 'Din faktura',
    'remove_contact' => 'Fjern kontakt',
    'add_contact' => 'Tilføj kontakt',
    'create_new_client' => 'Opret ny kunde',
    'edit_client_details' => 'Redigér kundedetaljer',
    'enable' => 'Aktivér',
    'learn_more' => 'Lær mere',
    'manage_rates' => 'Administrer priser',
    'note_to_client' => 'Bemærkning til kunde',
    'invoice_terms' => 'Vilkår for fakturaen',
    'save_as_default_terms' => 'Gem som standard vilkår',
    'download_pdf' => 'Hent PDF',
    'pay_now' => 'Betal nu',
    'save_invoice' => 'Gem faktura',
    'clone_invoice' => 'Kopiér til faktura',
    'archive_invoice' => 'Arkivér faktura',
    'delete_invoice' => 'Slet faktura',
    'email_invoice' => 'Send faktura som e-mail',
    'enter_payment' => 'Tilføj betaling',
    'tax_rates' => 'Momssatser',
    'rate' => 'Sats',
    'settings' => 'Indstillinger',
    'enable_invoice_tax' => 'Aktivér for at specificere en <b>moms</b>',
    'enable_line_item_tax' => 'Aktivér for at specificere pr. linje<b>moms</b>',
    'dashboard' => 'Oversigt',
    'dashboard_totals_in_all_currencies_help' => 'Note: tilføj et :link med navnet ":name" for at vise totaler ved at anvende en enkelt standard valuta.',
    'clients' => 'Kunder',
    'invoices' => 'Fakturaer',
    'payments' => 'Betalinger',
    'credits' => 'Kreditter',
    'history' => 'Historie',
    'search' => 'Søg',
    'sign_up' => 'Registrer dig',
    'guest' => 'Gæst',
    'company_details' => 'Virksomhedsinformation',
    'online_payments' => 'Onlinebetaling',
    'notifications' => 'Påmindelser',
    'import_export' => 'Import/Eksport',
    'done' => 'Færdig',
    'save' => 'Gem',
    'create' => 'Opret',
    'upload' => 'Send',
    'import' => 'Importer',
    'download' => 'Hent',
    'cancel' => 'Annuller',
    'close' => 'Luk',
    'provide_email' => 'Angiv venligst en gyldig e-mail',
    'powered_by' => 'Drevet af',
    'no_items' => 'Ingen emner',
    'recurring_invoices' => 'Gentagende fakturaer',
    'recurring_help' => '<p>Send automatisk klienter de samme fakturaer ugentligt, månedligt, hver anden måned, kvartalsvis eller årligt. </p>
        <p>Brug :MONTH, :QUARTER eller :YEAR ved dynamiske datoer. Basal matematik virker også, for eksempel :MONTH-1.</p>
        <p>Eksempler på dynamiske fakturavariabler:</p>
        <ul>
          <li>"Fitness medlemskab for :MONTH" >> "Fitness medlemskab for Juli"</li>
          <li>":YEAR+1 årligt abonnement" >> "2015 Årligt abonnement"</li>
          <li>"Tilbagebetaling vedrørende :QUARTER+1" >> "Tilbagebetaling vedrørende 2. kvartal"</li>
        </ul>',
    'recurring_quotes' => 'Gentagne tilbud',
    'in_total_revenue' => 'i samlet indtægt',
    'billed_client' => 'faktureret kunde',
    'billed_clients' => 'fakturerede kunder',
    'active_client' => 'aktiv kunde',
    'active_clients' => 'aktive kunder',
    'invoices_past_due' => 'Forfaldne fakturaer',
    'upcoming_invoices' => 'Kommende fakturaer',
    'average_invoice' => 'Gennemsnitlig fakturaer',
    'archive' => 'Arkiv',
    'delete' => 'Slet',
    'archive_client' => 'Arkivér kunde',
    'delete_client' => 'Slet kunde',
    'archive_payment' => 'Arkivér betaling',
    'delete_payment' => 'Slet betaling',
    'archive_credit' => 'Arkivér kredit',
    'delete_credit' => 'Slet kredit',
    'show_archived_deleted' => 'Vis arkiverede/slettede',
    'filter' => 'Filter',
    'new_client' => 'Ny kunde',
    'new_invoice' => 'Ny faktura',
    'new_payment' => 'Indtast betaling',
    'new_credit' => 'Indtast kredit',
    'contact' => 'Kontakt',
    'date_created' => 'Dato oprettet',
    'last_login' => 'Sidst set',
    'balance' => 'Balance',
    'action' => 'Handling',
    'status' => 'Status',
    'invoice_total' => 'Faktura total',
    'frequency' => 'Frekvens',
    'range' => 'Interval',
    'start_date' => 'Startdato',
    'end_date' => 'Slutdato',
    'transaction_reference' => 'Transaktionsreference',
    'method' => 'Betalingsmåde',
    'payment_amount' => 'Beløb',
    'payment_date' => 'Betalingsdato',
    'credit_amount' => 'Kreditbeløb',
    'credit_balance' => 'Kreditsaldo',
    'credit_date' => 'Kreditdato',
    'empty_table' => 'Ingen data er tilgængelige i tabellen',
    'select' => 'Vælg',
    'edit_client' => 'Rediger kunde',
    'edit_invoice' => 'Rediger faktura',
    'create_invoice' => 'Opret faktura',
    'enter_credit' => 'Tilføj kredit',
    'last_logged_in' => 'Senest logget ind',
    'details' => 'Detaljer',
    'standing' => 'Stående',
    'credit' => 'Kredit',
    'activity' => 'Aktivitet',
    'date' => 'Dato',
    'message' => 'Besked',
    'adjustment' => 'Justering',
    'are_you_sure' => 'Er du sikker?',
    'payment_type_id' => 'Betalingsmetode',
    'amount' => 'Beløb',
    'work_email' => 'E-mail',
    'language_id' => 'Sprog',
    'timezone_id' => 'Tidszone',
    'date_format_id' => 'Datoformat',
    'datetime_format_id' => 'Dato/Tidsformat',
    'users' => 'Brugere',
    'localization' => 'Lokalisering',
    'remove_logo' => 'Slet logo',
    'logo_help' => 'Understøttede filtyper: JPEG, GIF og PNG',
    'payment_gateway' => 'Betalingsgateway',
    'gateway_id' => 'Gateway',
    'email_notifications' => 'Notifikation via e-mail',
    'email_sent' => 'Notifikation når en faktura er <b>sendt</b>',
    'email_viewed' => 'Notifikation når en faktura er <b>set</b>',
    'email_paid' => 'Notifikation når en faktura er <b>betalt</b>',
    'site_updates' => 'Webside-opdateringer',
    'custom_messages' => 'Tilpassede meldinger',
    'default_email_footer' => 'Sæt standard e-mailsignatur',
    'select_file' => 'Venligst vælg en fil',
    'first_row_headers' => 'Brug første række som overskrifter',
    'column' => 'Kolonne',
    'sample' => 'Eksempel',
    'import_to' => 'Importer til',
    'client_will_create' => 'Kunde vil blive oprettet',
    'clients_will_create' => 'Kunder vil blive oprettet',
    'email_settings' => 'E-mail-indstillinger',
    'client_view_styling' => 'Kunde visning opsætning',
    'pdf_email_attachment' => 'Vedhæft PDF',
    'custom_css' => 'Brugerdefineret CSS',
    'import_clients' => 'Importer kundedata',
    'csv_file' => 'Vælg CSV-fil',
    'export_clients' => 'Eksporter kundedata',
    'created_client' => 'Kunde oprettet succesfuldt',
    'created_clients' => 'Kunder oprettet succesfuldt',
    'updated_settings' => 'Indstillinger opdateret',
    'removed_logo' => 'Logo slettet',
    'sent_message' => 'Besked sendt',
    'invoice_error' => 'Vælg venligst en kunde og ret eventuelle fejl',
    'limit_clients' => 'Desværre, dette vil overstige grænsen på :count kunder',
    'payment_error' => 'Det opstod en fejl under din betaling. Venligst prøv igen senere.',
    'registration_required' => 'Venligst registrer dig for at sende e-mail faktura',
    'confirmation_required' => 'Venligst bekræft e-mail, :link Send bekræftelses e-mail igen.',
    'updated_client' => 'Kunde opdateret',
    'archived_client' => 'Kunde arkiveret',
    'archived_clients' => 'Arkiverede :count kunder',
    'deleted_client' => 'Kunde slettet',
    'deleted_clients' => 'Slettede :count kunder',
    'updated_invoice' => 'Faktura opdateret',
    'created_invoice' => 'Faktura oprettet',
    'cloned_invoice' => 'Faktura kopieret',
    'emailed_invoice' => 'E-mail faktura sendt',
    'and_created_client' => 'og kunde oprettet',
    'archived_invoice' => 'Faktura arkiveret',
    'archived_invoices' => 'Arkiverede :count fakturaer',
    'deleted_invoice' => 'Faktura slettet',
    'deleted_invoices' => 'Slettede :count fakturaer',
    'created_payment' => 'Betaling oprettet',
    'created_payments' => 'Oprettet :count betaling(er)',
    'archived_payment' => 'Betaling arkiveret',
    'archived_payments' => 'Arkiverede :count betalinger',
    'deleted_payment' => 'Betaling slettet',
    'deleted_payments' => 'Slettede :count betalinger',
    'applied_payment' => 'Betaling ajourført',
    'created_credit' => 'Kredit oprettet',
    'archived_credit' => 'Kredit arkiveret',
    'archived_credits' => 'Arkiverede :count kreditter',
    'deleted_credit' => 'Kredit slettet',
    'deleted_credits' => 'Slettede :count kreditter',
    'imported_file' => 'Importerede filen succesfuldt',
    'updated_vendor' => ' Sælger opdateret succesfuldt',
    'created_vendor' => 'Sælger oprettet',
    'archived_vendor' => 'Gennemførte arkivering af sælger',
    'archived_vendors' => 'Gennemførte arkivering af :count sælgere',
    'deleted_vendor' => 'Sletning af sælger gennemført',
    'deleted_vendors' => 'Gennemførte sletning af :count sælgere',
    'confirmation_subject' => 'Bekræftelse af Invoice Ninja-konto',
    'confirmation_header' => 'Bekræftelse af konto',
    'confirmation_message' => 'Venligst klik på linket nedenfor for at bekræfte din konto.',
    'invoice_subject' => 'Ny faktura :number fra :account',
    'invoice_message' => 'For at se din faktura på :amount, klik på linket nedenfor.',
    'payment_subject' => 'Betaling modtaget',
    'payment_message' => 'Tak for din betaling pålydende :amount.',
    'email_salutation' => 'Kære :name,',
    'email_signature' => 'Venlig hilsen,',
    'email_from' => 'Invoice Ninja Teamet',
    'invoice_link_message' => 'For at se faktura, så klik på linket under:',
    'notification_invoice_paid_subject' => 'Faktura :invoice betalt af :client',
    'notification_invoice_sent_subject' => 'Faktura :invoice sendt til :client',
    'notification_invoice_viewed_subject' => 'Faktura :invoice set af :client',
    'notification_invoice_paid' => 'En betaling pålydende :amount blev betalt af :client for faktura :invoice.',
    'notification_invoice_sent' => 'En e-mail er blevet sendt til :client med faktura :invoice pålydende :amount.',
    'notification_invoice_viewed' => ':client har set faktura :invoice pålydende :amount.',
    'reset_password' => 'Du kan nulstille din adgangskode ved at besøge følgende link:',
    'secure_payment' => 'Sikker betaling',
    'card_number' => 'Kortnummer',
    'expiration_month' => 'Udløbsdato',
    'expiration_year' => 'Udløbsår',
    'cvv' => 'Kontrolcifre',
    'logout' => 'Log ud',
    'sign_up_to_save' => 'Registrer dig for at gemme dit arbejde',
    'agree_to_terms' => 'Jeg accepterer :terms',
    'terms_of_service' => 'Vilkår for brug',
    'email_taken' => 'E-mailadressen er allerede registreret',
    'working' => 'Arbejder',
    'success' => 'Succes',
    'success_message' => 'Du er blevet registreret. Klik på linket som du har modtaget i e-mail bekræftelsen for at bekræfte din e-mail adresse.',
    'erase_data' => 'Din konto er ikke registreret, dette vil slette dine data.',
    'password' => 'Kodeord',
    'pro_plan_product' => 'Pro Plan',
    'pro_plan_success' => 'Tak fordi du valgte Invoice Ninja\'s Pro plan!<p/>&nbsp;<br/>
                  <b>De næste skridt</b><p/>En betalbar faktura er sendt til den e-mail adresse
                  som er tilknyttet din konto. For at låse op for alle de utrolige
                  Pro-funktioner, skal du følge instruktionerne på fakturaen til at
                  betale for et år med fakturering på Pro-niveau.<p/>
                  Kan du ikke finde fakturaen? Har behov for mere hjælp? Vi hjælper dig gerne hvis der skulle være noget galt
                  -- kontakt os på contact@invoiceninja.com',
    'unsaved_changes' => 'Du har ændringer som ikke er gemt',
    'custom_fields' => 'Brugerdefineret felt',
    'company_fields' => 'Selskabets felt',
    'client_fields' => 'Kundefelt',
    'field_label' => 'Felt-etikette',
    'field_value' => 'Feltets værdi',
    'edit' => 'Rediger',
    'set_name' => 'Sæt dit firmanavn',
    'view_as_recipient' => 'Vis som modtager',
    'product_library' => 'Produktbibliotek',
    'product' => 'Produkt',
    'products' => 'Produkter',
    'fill_products' => 'Automatisk-udfyld produkter',
    'fill_products_help' => 'Valg af produkt vil automatisk udfylde <b>beskrivelse og pris</b>',
    'update_products' => 'Automatisk opdatering af produkter',
    'update_products_help' => 'En opdatering af en faktura vil automatisk <b>opdaterer Produkt biblioteket</b>',
    'create_product' => 'Opret nyt produkt',
    'edit_product' => 'Rediger produkt',
    'archive_product' => 'Arkivér produkt',
    'updated_product' => 'Produkt opdateret',
    'created_product' => 'Produkt oprettet',
    'archived_product' => 'Produkt arkiveret',
    'pro_plan_custom_fields' => ':link for at aktivere egendefinerede felter skal du have en Pro Plan',
    'advanced_settings' => 'Avancerede indstillinger',
    'pro_plan_advanced_settings' => ':link for at aktivere avancerede indstillinger skal du være have en Pro Plan',
    'invoice_design' => 'Fakturadesign',
    'specify_colors' => 'Brugerdefineret farve',
    'specify_colors_label' => 'Vælg de farver som skal bruges i fakturaen',
    'chart_builder' => 'Diagram-bygger',
    'ninja_email_footer' => 'Oprettet af :site | Opret. Send. Få betaling.',
    'go_pro' => 'Vælg Pro',
    'quote' => 'Pristilbud',
    'quotes' => 'Pristilbud',
    'quote_number' => 'Tilbuds nummer',
    'quote_number_short' => 'Tilbuds #',
    'quote_date' => 'Tilbuds dato',
    'quote_total' => 'Tilbud total',
    'your_quote' => 'Dit tilbud',
    'total' => 'Total',
    'clone' => 'Kopiér',
    'new_quote' => 'Nyt tilbud',
    'create_quote' => 'Opret tilbud',
    'edit_quote' => 'Rediger tilbud',
    'archive_quote' => 'Arkivér tilbud',
    'delete_quote' => 'Slet tilbud',
    'save_quote' => 'Gem tilbud',
    'email_quote' => 'E-mail tilbuddet',
    'clone_quote' => 'Klon til tilbud',
    'convert_to_invoice' => 'Konvertér til en faktura',
    'view_invoice' => 'Se faktura',
    'view_client' => 'Se kunde',
    'view_quote' => 'Se tilbud',
    'updated_quote' => 'Tilbud opdateret',
    'created_quote' => 'Tilbud oprettet',
    'cloned_quote' => 'Tilbud kopieret',
    'emailed_quote' => 'Tilbud sendt som e-mail',
    'archived_quote' => 'Tilbud arkiveret',
    'archived_quotes' => 'Arkiverede :count tilbud',
    'deleted_quote' => 'Tilbud slettet',
    'deleted_quotes' => 'Slettede :count tilbud',
    'converted_to_invoice' => 'Tilbud konverteret til faktura',
    'quote_subject' => 'Nyt tilbud :number fra :account',
    'quote_message' => 'For at se tilbud pålydende :amount, klik på linket nedenfor.',
    'quote_link_message' => 'For at se kundetilbud, klik på linket under:',
    'notification_quote_sent_subject' => 'Tilbud :invoice sendt til :client',
    'notification_quote_viewed_subject' => 'Tilbudet :invoice er set af :client',
    'notification_quote_sent' => 'Følgende kunde :client blev tilsendt tilbudsfaktura :invoice pålydende :amount.',
    'notification_quote_viewed' => 'Følgende kunde :client har set tilbudsfakturaen :invoice pålydende :amount.',
    'session_expired' => 'Session er udløbet.',
    'invoice_fields' => 'Faktura felt',
    'invoice_options' => 'Fakturaindstillinger',
    'hide_paid_to_date' => 'Skjul delbetalinger',
    'hide_paid_to_date_help' => 'Vis kun delbetalinger hvis der er forekommet en delbetaling.',
    'charge_taxes' => 'Inkluder skat',
    'user_management' => 'Brugerhåndtering',
    'add_user' => 'Tilføj bruger',
    'send_invite' => 'Send invitation',
    'sent_invite' => 'Invitation sendt',
    'updated_user' => 'Bruger opdateret',
    'invitation_message' => 'Du er blevet inviteret af :invitor. ',
    'register_to_add_user' => 'Du skal registrer dig for at oprette en bruger',
    'user_state' => 'Status',
    'edit_user' => 'Rediger bruger',
    'delete_user' => 'Slet bruger',
    'active' => 'Aktiv',
    'pending' => 'Afventer',
    'deleted_user' => 'Bruger slettet',
    'confirm_email_invoice' => 'Er du sikker på at du vil sende en e-mail med denne faktura?',
    'confirm_email_quote' => 'Er du sikker på du ville sende en e-mail med dette tilbud?',
    'confirm_recurring_email_invoice' => 'Gentagende er slået til, er du sikker på du sende en e-mail med denne faktura?',
    'confirm_recurring_email_invoice_not_sent' => 'Er du sikker på at du vil begynde gentagelsen',
    'cancel_account' => 'Annuller konto',
    'cancel_account_message' => 'ADVARSEL: Dette vil permanent slette din konto, der er INGEN mulighed for at fortryde.',
    'go_back' => 'Gå tilbage',
    'data_visualizations' => 'Datavisualisering',
    'sample_data' => 'Eksempel data vist',
    'hide' => 'Skjul',
    'new_version_available' => 'En ny version af :releases_link er tilgængelig. Din nuværende version er v:user_version, den nyeste version er v:latest_version',
    'invoice_settings' => 'Fakturaindstillinger',
    'invoice_number_prefix' => 'Fakturanummer-præfiks',
    'invoice_number_counter' => 'Fakturanummer-tæller',
    'quote_number_prefix' => 'Tilbuds nummer-præfiks',
    'quote_number_counter' => 'Tilbuds nummer-tæller',
    'share_invoice_counter' => 'Del faktura nummer tæller',
    'invoice_issued_to' => 'Faktura udstedt til',
    'invalid_counter' => 'For at undgå mulige overlap, sæt et faktura eller tilbuds nummer præfiks',
    'mark_sent' => 'Markér som sendt',
    'gateway_help_1' => ':link til at registrere dig hos Authorize.net.',
    'gateway_help_2' => ':link til at registrere dig hos Authorize.net.',
    'gateway_help_17' => ':link til at hente din PayPal API signatur.',
    'gateway_help_27' => ':link for at oprette sig hos 2Checkout.com. For at sikre at betalinger er fulgt sæt :complete_link som redirect URL under Konto > Side Management i 2Checkout portalen.',
    'gateway_help_60' => ':link til at oprette en WePay konto',
    'more_designs' => 'Flere designs',
    'more_designs_title' => 'Yderligere fakturadesigns',
    'more_designs_cloud_header' => 'Skift til Pro for flere fakturadesigns',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Køb',
    'bought_designs' => 'Yderligere fakturadesigns tilføjet',
    'sent' => 'Sendt',
    'vat_number' => 'CVR/SE-nummer',
    'timesheets' => 'Timesedler',
    'payment_title' => 'Indtast din fakturaadresse og kreditkortinformation',
    'payment_cvv' => 'Dette er det 3-4 cifrede nummer på bagsiden af dit kort',
    'payment_footer1' => '*Fakturaadressen skal matche den der er tilknyttet kortet.',
    'payment_footer2' => '*Klik kun på "Betal Nu" én gang - transaktionen kan tage helt op til 1 minut inden den er færdig.',
    'id_number' => 'CVR/SE-nummer',
    'white_label_link' => 'Hvidmærket',
    'white_label_header' => 'Hvidmærket',
    'bought_white_label' => 'Hvidmærket licens accepteret',
    'white_labeled' => 'Hvidmærke',
    'restore' => 'Genskab',
    'restore_invoice' => 'Genskab faktura',
    'restore_quote' => 'Genskab tilbud',
    'restore_client' => 'Genskab kunde',
    'restore_credit' => 'Genskab kredit',
    'restore_payment' => 'Genskab betaling',
    'restored_invoice' => 'Faktura genskabt',
    'restored_quote' => 'Tilbud genskabt',
    'restored_client' => 'Kunde genskabt',
    'restored_payment' => 'Betaling genskabt',
    'restored_credit' => 'Kredit genskabt',
    'reason_for_canceling' => 'Hjælp os med at blive bedre ved at fortælle os hvorfor du forlader os.',
    'discount_percent' => 'Procent',
    'discount_amount' => 'Beløb',
    'invoice_history' => 'Fakturahistorik',
    'quote_history' => 'Tilbudshistorik',
    'current_version' => 'Nuværende version',
    'select_version' => 'Vælg version',
    'view_history' => 'Vis historik',
    'edit_payment' => 'Redigér betaling',
    'updated_payment' => 'Betaling opdateret',
    'deleted' => 'Slettet',
    'restore_user' => 'Genskab bruger',
    'restored_user' => 'Bruger genskabt',
    'show_deleted_users' => 'Vis slettede brugere',
    'email_templates' => 'E-mail skabeloner',
    'invoice_email' => 'Faktura e-mail',
    'payment_email' => 'Betalings e-mail',
    'quote_email' => 'Tilbuds e-mail',
    'reset_all' => 'Nulstil alle',
    'approve' => 'Godkend',
    'token_billing_type_id' => 'Tokensk Fakturering',
    'token_billing_help' => 'Gem betalingsoplysninger med WePay, Stripe, Braintree eller GoCardless.',
    'token_billing_1' => 'Slukket',
    'token_billing_2' => 'Tilvalg - checkboks er vist men ikke valgt',
    'token_billing_3' => 'Fravalg - checkboks er vist og valgt',
    'token_billing_4' => 'Altid',
    'token_billing_checkbox' => 'Opbevar kreditkort oplysninger',
    'view_in_gateway' => 'Vis i :gateway',
    'use_card_on_file' => 'Anvend tidligere gemt kort',
    'edit_payment_details' => 'Redigér betalings detaljer',
    'token_billing' => 'Gem kort detaljer',
    'token_billing_secure' => 'Kort data er opbevaret sikkert hos :link',
    'support' => 'Kundeservice',
    'contact_information' => 'Kontakt information',
    '256_encryption' => '256-Bit Kryptering',
    'amount_due' => 'Beløb forfaldent',
    'billing_address' => 'Faktura adresse',
    'billing_method' => 'Faktureringsmetode',
    'order_overview' => 'Ordreoversigt',
    'match_address' => '*Adressen skal matche det tilknyttede kreditkort.',
    'click_once' => '**Klik kun på "Betal Nu" én gang - transaktionen kan tage helt op til 1 minut inden den er færdig.',
    'invoice_footer' => 'Faktura fodnoter',
    'save_as_default_footer' => 'Gem som standard fodnoter',
    'token_management' => 'Token Administration',
    'tokens' => 'Token\'s',
    'add_token' => 'Tilføj token',
    'show_deleted_tokens' => 'Vis slettede token\'s',
    'deleted_token' => 'Token slettet',
    'created_token' => 'Token oprettet',
    'updated_token' => 'Token opdateret',
    'edit_token' => 'Redigér token',
    'delete_token' => 'Slet token',
    'token' => 'Token',
    'add_gateway' => 'Tilføj gateway',
    'delete_gateway' => 'Slet gateway',
    'edit_gateway' => 'Redigér gateway',
    'updated_gateway' => 'Gateway blev opdateret',
    'created_gateway' => 'Gateway blev oprettet',
    'deleted_gateway' => 'Gateway blev slettet',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Kredit kort',
    'change_password' => 'Skift adgangskode',
    'current_password' => 'Nuværende adgangskode',
    'new_password' => 'Ny adgangskode',
    'confirm_password' => 'Bekræft adgangskode',
    'password_error_incorrect' => 'Den nuværende adgangskode er forkert.',
    'password_error_invalid' => 'Den nye adgangskode er ugyldig.',
    'updated_password' => 'Adgangskode opdateret',
    'api_tokens' => 'API Token\'s',
    'users_and_tokens' => 'Brugere & Token\'s',
    'account_login' => 'Konto Log ind',
    'recover_password' => 'Generhverv din adgangskode',
    'forgot_password' => 'Glemt din adgangskode?',
    'email_address' => 'E-mail adresse',
    'lets_go' => 'Og så afsted',
    'password_recovery' => 'Adgangskode Generhvervelse',
    'send_email' => 'Send e-mail',
    'set_password' => 'Sæt adgangskode',
    'converted' => 'Konverteret',
    'email_approved' => 'E-mail mig når et tilbud er <b>accepteret</b>',
    'notification_quote_approved_subject' => 'Tilbudet :invoice blev accepteret af :client',
    'notification_quote_approved' => 'Den følgende kunde :client accepterede tilbud :invoice lydende på :amount.',
    'resend_confirmation' => 'Send bekræftelses e-mail igen',
    'confirmation_resent' => 'Bekræftelses e-mail er afsendt',
    'gateway_help_42' => ':link til registrering hos BitPay.<br/>Bemærk: brug en use a Legacy API nøgle, og ikke en API token.',
    'payment_type_credit_card' => 'Kredit kort',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Vidensbase',
    'partial' => 'Udbetaling',
    'partial_remaining' => ':partial af :balance',
    'more_fields' => 'Flere felter',
    'less_fields' => 'Mindre felter',
    'client_name' => 'Kundenavn',
    'pdf_settings' => 'PDF Indstillinger',
    'product_settings' => 'Produkt Indstillinger',
    'auto_wrap' => 'Automatisk linie ombrydning',
    'duplicate_post' => 'Advarsel: den foregående side blev sendt to gange. Den anden afsendelse er blevet ignoreret.',
    'view_documentation' => 'Vis dokumentation',
    'app_title' => 'Gratis Open-Source Online fakturering',
    'app_description' => 'Invoice Ninja er en gratis, open-source løsning til at håndtere fakturering og betaling af dine kunder. Med Invoice Ninja, kan du let generere og sende smukke fakturaer fra et hvilket som helst udstyr der har adgang til internettet. Dine klienter kan udskrive dine fakturarer, hente dem som PDF filer, og endda betale dem on-line inde fra Invoice Ninja.',
    'rows' => 'rækker',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'Underdomain',
    'provide_name_or_email' => 'Venligst angiv et navn eller e-mail',
    'charts_and_reports' => 'Diagrammer & Rapporter',
    'chart' => 'Diagram',
    'report' => 'Rapport',
    'group_by' => 'Gruppér efter',
    'paid' => 'Betalt',
    'enable_report' => 'Rapport',
    'enable_chart' => 'Diagram',
    'totals' => 'Totaler',
    'run' => 'Kør',
    'export' => 'Eksport',
    'documentation' => 'Dokumentation',
    'zapier' => 'Zapier',
    'recurring' => 'Gentagne',
    'last_invoice_sent' => 'Sidste faktura sendt :date',
    'processed_updates' => 'Opdatering gennemført',
    'tasks' => 'Opgaver',
    'new_task' => 'Ny opgave',
    'start_time' => 'Start Tidspunkt',
    'created_task' => 'Opgave oprettet',
    'updated_task' => 'Opgave opdateret',
    'edit_task' => 'Redigér opgave',
    'clone_task' => 'Klon opgave',
    'archive_task' => 'Arkiver opgave',
    'restore_task' => 'Genskab opgave',
    'delete_task' => 'Slet opgave',
    'stop_task' => 'Stop opgave',
    'time' => 'Tid',
    'start' => 'Start',
    'stop' => 'Stop',
    'now' => 'Nu',
    'timer' => 'Tidtager',
    'manual' => 'Manuelt',
    'date_and_time' => 'Dato & Tid',
    'second' => 'Sekund',
    'seconds' => 'Sekunder',
    'minute' => 'Minut',
    'minutes' => 'Minutter',
    'hour' => 'Time',
    'hours' => 'Timer',
    'task_details' => 'Opgave detaljer',
    'duration' => 'Varighed',
    'time_log' => 'Tids log',
    'end_time' => 'Slut tidspunkt',
    'end' => 'Slut',
    'invoiced' => 'Faktureret',
    'logged' => 'Ajourført',
    'running' => 'Kører',
    'task_error_multiple_clients' => 'Opgaverne kan ikke tilhøre forskellige kunder',
    'task_error_running' => 'Stop alle kørende opgaver først',
    'task_error_invoiced' => 'Opgaver er allerede faktureret',
    'restored_task' => 'Opgave genskabt',
    'archived_task' => 'Opgave arkiveret',
    'archived_tasks' => 'Antal arkiverede opgaver: :count',
    'deleted_task' => 'Opgave slettet',
    'deleted_tasks' => 'Antal opgaver slettet: :count',
    'create_task' => 'Opret opgave',
    'stopped_task' => 'Opgave stoppet',
    'invoice_task' => 'Fakturer opgave',
    'invoice_labels' => 'Faktura labels',
    'prefix' => 'Præfix',
    'counter' => 'Tæller',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link til at registrere dig hos Dwolla.',
    'partial_value' => 'Skal være større end nul og mindre end totalen',
    'more_actions' => 'Flere handlinger',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Opgradér Nu!',
    'pro_plan_feature1' => 'Opret ubegrænset antal kunder',
    'pro_plan_feature2' => 'Adgang til 10 smukke faktura designs',
    'pro_plan_feature3' => 'Tilpasset URL - "YourBrand.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Fjern "Created by Invoice Ninja"',
    'pro_plan_feature5' => 'Multi bruger adgang og aktivitets log',
    'pro_plan_feature6' => 'Opret tilbud og proforma fakturaer',
    'pro_plan_feature7' => 'Brugerdefinerede faktura felt titler og nummerering',
    'pro_plan_feature8' => 'Mulighed for at vedhæfte PDF filer til klient e-mails',
    'resume' => 'Genoptag',
    'break_duration' => 'Pause',
    'edit_details' => 'Rediger detaljer',
    'work' => 'Arbejde',
    'timezone_unset' => 'Indstil :link din tidszone',
    'click_here' => 'Klik her',
    'email_receipt' => 'Send e-mail kvittering til kunden',
    'created_payment_emailed_client' => 'Betaling modtaget og e-mail kvittering sendt til klienten',
    'add_company' => 'Tilføj firma',
    'untitled' => 'Ingen titel',
    'new_company' => 'Nyt firma',
    'associated_accounts' => 'Konti sammenkædet',
    'unlinked_account' => 'Sammenkædning af konti ophævet',
    'login' => 'Log ind',
    'or' => 'eller',
    'email_error' => 'Der opstod et problem ved afsendelse af e-mailen',
    'confirm_recurring_timing' => 'Bemærk: e-mail bliver sendt i starten af timen.',
    'confirm_recurring_timing_not_sent' => 'Note: Fakturaer genereres i starten af en time ',
    'payment_terms_help' => 'Sætter standard <b>faktura forfalds dato</b>',
    'unlink_account' => 'Fjern sammenkædning af konti',
    'unlink' => 'Fjern sammenkædning',
    'show_address' => 'Vis adresse',
    'show_address_help' => 'Kræv at kunden angiver faktureringsadresse',
    'update_address' => 'Opdater adresse',
    'update_address_help' => 'Opdater kundens adresse med de opgivne detaljer',
    'times' => 'Gange',
    'set_now' => 'Sæt nu',
    'dark_mode' => 'Mørk tilstand',
    'dark_mode_help' => 'Brug en mørk baggrund til sidebars',
    'add_to_invoice' => 'Tilføj til faktura nr.: :invoice',
    'create_new_invoice' => 'Opret ny faktura',
    'task_errors' => 'Ret venligst de overlappende tider',
    'from' => 'Fra',
    'to' => 'Til',
    'font_size' => 'Font Størrelse',
    'primary_color' => 'Primær Farve',
    'secondary_color' => 'Sekundær Farve',
    'customize_design' => 'Tilpas Design',
    'content' => 'Indhold',
    'styles' => 'Stilarter',
    'defaults' => 'Standarder',
    'margins' => 'Marginer',
    'header' => 'Hoved',
    'footer' => 'Fod',
    'custom' => 'Brugertilpasset',
    'invoice_to' => 'Fakturer til',
    'invoice_no' => 'Faktura Nr.',
    'quote_no' => 'Tilbud nr.',
    'recent_payments' => 'Nylige betalinger',
    'outstanding' => 'Forfaldne',
    'manage_companies' => 'Manage Companies',
    'total_revenue' => 'Samlede indtægter',
    'current_user' => 'Nuværende bruger',
    'new_recurring_invoice' => 'Ny gentaget fakture',
    'recurring_invoice' => 'Gentaget faktura',
    'new_recurring_quote' => 'Nyt gentaget tilbud',
    'recurring_quote' => 'Gentaget tilbud',
    'recurring_too_soon' => 'Det er for tidligt at generere den næste faktura, it\'s scheduled for :date',
    'created_by_invoice' => 'Oprettet fra :invoice',
    'primary_user' => 'Primær bruger',
    'help' => 'Hjælp',
    'customize_help' => '<p>Vi bruger :pdfmake_link til at definere fakturadesigns deklarativt. Pdfmaker :playground_link tilbyder en glimrende mulighed for at se biblioteket i aktion.</p>
<p>Hvis du har brug for hjælp, send et spørgsmål til vores: forum_link med det design, du bruger.</p>',
    'playground' => 'legeplads',
    'support_forum' => 'support forum',
    'invoice_due_date' => 'Due Date',
    'quote_due_date' => 'Gyldig indtil',
    'valid_until' => 'Gyldig indtil',
    'reset_terms' => 'Reset terms',
    'reset_footer' => 'Reset footer',
    'invoice_sent' => ':count fakturaer sendt',
    'invoices_sent' => ':count fakturaer sendt',
    'status_draft' => 'Draft',
    'status_sent' => 'Sent',
    'status_viewed' => 'Viewed',
    'status_partial' => 'Partial',
    'status_paid' => 'Paid',
    'status_unpaid' => 'Ubetalt',
    'status_all' => 'Alle',
    'show_line_item_tax' => 'Display <b>line item taxes</b> inline',
    'iframe_url' => 'Website',
    'iframe_url_help1' => 'Copy the following code to a page on your site.',
    'iframe_url_help2' => 'You can test the feature by clicking \'View as recipient\' for an invoice.',
    'auto_bill' => 'Auto Bill',
    'military_time' => '24 Hour Time',
    'last_sent' => 'Last Sent',
    'reminder_emails' => 'Reminder Emails',
    'quote_reminder_emails' => 'Tilbuds påmindelses e-mails',
    'templates_and_reminders' => 'Templates & Reminders',
    'subject' => 'Subject',
    'body' => 'Body',
    'first_reminder' => 'First Reminder',
    'second_reminder' => 'Second Reminder',
    'third_reminder' => 'Third Reminder',
    'num_days_reminder' => 'Days after due date',
    'reminder_subject' => 'Reminder: Invoice :invoice from :account',
    'reset' => 'Reset',
    'invoice_not_found' => 'The requested invoice is not available',
    'referral_program' => 'Referral Program',
    'referral_code' => 'Referral Code',
    'last_sent_on' => 'Last sent on :date',
    'page_expire' => 'This page will expire soon, :click_here to keep working',
    'upcoming_quotes' => 'Upcoming Quotes',
    'expired_quotes' => 'Expired Quotes',
    'sign_up_using' => 'Sign up using',
    'invalid_credentials' => 'These credentials do not match our records',
    'show_all_options' => 'Show all options',
    'user_details' => 'User Details',
    'oneclick_login' => 'Forbundet konto',
    'disable' => 'Disable',
    'invoice_quote_number' => 'Invoice and Quote Numbers',
    'invoice_charges' => 'Faktura tillægsgebyr',
    'notification_invoice_bounced' => 'We were unable to deliver Invoice :invoice to :contact.',
    'notification_invoice_bounced_subject' => 'Unable to deliver Invoice :invoice',
    'notification_quote_bounced' => 'We were unable to deliver Quote :invoice to :contact.',
    'notification_quote_bounced_subject' => 'Unable to deliver Quote :invoice',
    'custom_invoice_link' => 'Custom Invoice Link',
    'total_invoiced' => 'Faktureret ialt',
    'open_balance' => 'Udestående:',
    'verify_email' => 'Please visit the link in the account confirmation email to verify your email address.',
    'basic_settings' => 'Basic Settings',
    'pro' => 'Pro',
    'gateways' => 'Betalingsgateways',
    'next_send_on' => 'Send Next: :date',
    'no_longer_running' => 'This invoice is not scheduled to run',
    'general_settings' => 'General Settings',
    'customize' => 'Customize',
    'oneclick_login_help' => 'Connect an account to login without a password',
    'referral_code_help' => 'Earn money by sharing our app online',
    'enable_with_stripe' => 'Enable | Requires Stripe',
    'tax_settings' => 'Tax Settings',
    'create_tax_rate' => 'Add Tax Rate',
    'updated_tax_rate' => 'Successfully updated tax rate',
    'created_tax_rate' => 'Successfully created tax rate',
    'edit_tax_rate' => 'Edit tax rate',
    'archive_tax_rate' => 'Archive tax rate',
    'archived_tax_rate' => 'Successfully archived the tax rate',
    'default_tax_rate_id' => 'Default Tax Rate',
    'tax_rate' => 'Tax Rate',
    'recurring_hour' => 'Recurring Hour',
    'pattern' => 'Pattern',
    'pattern_help_title' => 'Pattern Help',
    'pattern_help_1' => 'Opret brugerdefineret nummer ved at specificere et mønster',
    'pattern_help_2' => 'Available variables:',
    'pattern_help_3' => 'For example, :example would be converted to :value',
    'see_options' => 'See options',
    'invoice_counter' => 'Invoice Counter',
    'quote_counter' => 'Quote Counter',
    'type' => 'Type',
    'activity_1' => ':user created client :client',
    'activity_2' => ':user arkiverede kunde :client',
    'activity_3' => ':user slettede kunde :client',
    'activity_4' => ':user oprettede faktura :invoice',
    'activity_5' => ':user ajourførte faktura :invoice',
    'activity_6' => ':user emailede fakturaen :invoice for :client til :contact',
    'activity_7' => ':contact læste faktura :invoice for :client',
    'activity_8' => ':user arkiverede faktura :invoice',
    'activity_9' => ':user slettede faktura :invoice',
    'activity_10' => ':contact indtastede betaling :payment for :payment_amout i fakturaen :invoice for :client',
    'activity_11' => ':user ajourførte betaling :payment',
    'activity_12' => ':user arkiverede betaling :payment',
    'activity_13' => ':user slettede betaling :payment',
    'activity_14' => ':user indtastede :credit kredit',
    'activity_15' => ':user ajourførte :credit kredit',
    'activity_16' => ':user arkiverede :credit kredit',
    'activity_17' => ':user slettede :credit kredit',
    'activity_18' => ':user oprettede tilbud :quote',
    'activity_19' => ':user ajourførte tilbud :quote',
    'activity_20' => ':user emailede tilbuddet :quote for :client til :contact',
    'activity_21' => ':contact læste tilbud :quote',
    'activity_22' => ':user arkiverede tilbud :quote',
    'activity_23' => ':user slettede tilbud:quote',
    'activity_24' => ':user genoprettede tilbud :quote',
    'activity_25' => ':user genoprettede faktura :invoice',
    'activity_26' => ':user genoprettede kunde :client',
    'activity_27' => ':user genoprettede betaling :payment',
    'activity_28' => ':user genoprettede :credit kredit',
    'activity_29' => ':contact godkendte tilbuddet :quote for :client',
    'activity_30' => ':user oprettede sælger :vendor',
    'activity_31' => ':user arkiverede sælger :vendor',
    'activity_32' => ':user slettede sælgeren :vendor',
    'activity_33' => ':user genskabte sælgeren :vendor',
    'activity_34' => ':user oprettede udgiften :expense',
    'activity_35' => ':user arkiverede udgiften :expense',
    'activity_36' => ':user slettede udgiften :expense',
    'activity_37' => ':user genskabte udgiften :expense',
    'activity_42' => ':user oprettede opgaven :task',
    'activity_43' => ':user opdaterede opgaven :task',
    'activity_44' => ':user arkiverede opgaven :task',
    'activity_45' => ':user slettede opgave :task',
    'activity_46' => ':user genoprettede opgave :task',
    'activity_47' => ':user ajourførte udgift :expense',
    'activity_48' => ':user opdaterede sagen :ticket',
    'activity_49' => ':user lukkede sagen :ticket',
    'activity_50' => ':user sammenflettede sagen :ticket',
    'activity_51' => ':user opdelte sagen :ticket',
    'activity_52' => ':contact åbnede sagen :ticket',
    'activity_53' => ':contact genåbnede sagen :ticket',
    'activity_54' => ':user genåbnede sagen :ticket',
    'activity_55' => ':contact besvarede sagen :ticket',
    'activity_56' => ':user læste sagen :ticket',

    'payment' => 'Betaling',
    'system' => 'System',
    'signature' => 'E-mail Signature',
    'default_messages' => 'Default Messages',
    'quote_terms' => 'Quote Terms',
    'default_quote_terms' => 'Default Quote Terms',
    'default_invoice_terms' => 'Sæt standard fakturavilkår',
    'default_invoice_footer' => 'Sæt standard faktura fodnoter',
    'quote_footer' => 'Quote Footer',
    'free' => 'Free',
    'quote_is_approved' => 'Tilbud er nu godkendt. Betal gerne med det samme',
    'apply_credit' => 'Apply Credit',
    'system_settings' => 'System Settings',
    'archive_token' => 'Archive Token',
    'archived_token' => 'Successfully archived token',
    'archive_user' => 'Archive User',
    'archived_user' => 'Successfully archived user',
    'archive_account_gateway' => 'Slet gateway',
    'archived_account_gateway' => 'Gateway blev arkiveret',
    'archive_recurring_invoice' => 'Archive Recurring Invoice',
    'archived_recurring_invoice' => 'Successfully archived recurring invoice',
    'delete_recurring_invoice' => 'Delete Recurring Invoice',
    'deleted_recurring_invoice' => 'Successfully deleted recurring invoice',
    'restore_recurring_invoice' => 'Restore Recurring Invoice',
    'restored_recurring_invoice' => 'Successfully restored recurring invoice',
    'archive_recurring_quote' => 'Arkivér tilbagevendende tilbud',
    'archived_recurring_quote' => 'Tilbagevendende tilbud blev arkiveret',
    'delete_recurring_quote' => 'Slet tilbagevendende tilbud',
    'deleted_recurring_quote' => 'Sletning af tilbagevendende tilbud er gennemført',
    'restore_recurring_quote' => 'Genskab tilbagevendende tilbud',
    'restored_recurring_quote' => 'Sletning af tilbagevendende tilbud er gennemført',
    'archived' => 'Archived',
    'untitled_account' => 'Untitled Company',
    'before' => 'Before',
    'after' => 'After',
    'reset_terms_help' => 'Reset to the default account terms',
    'reset_footer_help' => 'Reset to the default account footer',
    'export_data' => 'Export Data',
    'user' => 'User',
    'country' => 'Country',
    'include' => 'Include',
    'logo_too_large' => 'Your logo is :size, for better PDF performance we suggest uploading an image file less than 200KB',
    'import_freshbooks' => 'Import From FreshBooks',
    'import_data' => 'Import Data',
    'source' => 'Source',
    'csv' => 'CSV',
    'client_file' => 'Client File',
    'invoice_file' => 'Invoice File',
    'task_file' => 'Task File',
    'no_mapper' => 'No valid mapping for file',
    'invalid_csv_header' => 'Invalid CSV Header',
    'client_portal' => 'Client Portal',
    'admin' => 'Admin',
    'disabled' => 'Disabled',
    'show_archived_users' => 'Show archived users',
    'notes' => 'Notes',
    'invoice_will_create' => 'faktura vil blive oprettet',
    'invoices_will_create' => 'invoices will be created',
    'failed_to_import' => 'The following records failed to import, they either already exist or are missing required fields.',
    'publishable_key' => 'Publishable Key',
    'secret_key' => 'Secret Key',
    'missing_publishable_key' => 'Set your Stripe publishable key for an improved checkout process',
    'email_design' => 'Email Design',
    'due_by' => 'Forfald pr. :date',
    'enable_email_markup' => 'Brug HTML markup sprog',
    'enable_email_markup_help' => 'Gør det lettere for dine klienter at betale dig ved at tilføje schema.org markup i dine e-mails.',
    'template_help_title' => 'Templates Help',
    'template_help_1' => 'Available variables:',
    'email_design_id' => 'Email Style',
    'email_design_help' => 'Giv dine e-mails et mere professionelt udseende med HTML-layouts.',
    'plain' => 'Plain',
    'light' => 'Light',
    'dark' => 'Dark',
    'industry_help' => 'Used to provide comparisons against the averages of companies of similar size and industry.',
    'subdomain_help' => 'Angiv subdomænet eller vis fakturaen på din egen hjemmeside.',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the invoice number.',
    'quote_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the quote number.',
    'custom_client_fields_helps' => 'Tilføj et felt, når du opretter en klient, og vis eventuelt etiketten og værdien på PDF-filen.',
    'custom_account_fields_helps' => 'Add a label and value to the company details section of the PDF.',
    'custom_invoice_fields_helps' => 'Tilføj et felt, når du opretter en faktura, og vælg eventuelt at vise etiketten og værdien på PDF.',
    'custom_invoice_charges_helps' => 'Add a text input to the invoice create/edit page and include the charge in the invoice subtotals.',
    'token_expired' => 'Validation token was expired. Please try again.',
    'invoice_link' => 'Invoice Link',
    'button_confirmation_message' => 'Click to confirm your email address.',
    'confirm' => 'Confirm',
    'email_preferences' => 'Email Preferences',
    'created_invoices' => 'Successfully created :count invoice(s)',
    'next_invoice_number' => 'The next invoice number is :number.',
    'next_quote_number' => 'The next quote number is :number.',
    'days_before' => 'Dage før',
    'days_after' => 'Dage efter',
    'field_due_date' => 'due date',
    'field_invoice_date' => 'invoice date',
    'schedule' => 'Schedule',
    'email_designs' => 'Email Designs',
    'assigned_when_sent' => 'Assigned when sent',
    'white_label_purchase_link' => 'Erhvérv et hvidmærket license',
    'expense' => 'Expense',
    'expenses' => 'Udgifter',
    'new_expense' => 'Indtast udgift',
    'enter_expense' => 'Enter Expense',
    'vendors' => 'Sælgere',
    'new_vendor' => 'Ny sælger',
    'payment_terms_net' => 'Net',
    'vendor' => 'Sælger',
    'edit_vendor' => 'Redigér sælger',
    'archive_vendor' => 'Arkivér sælger',
    'delete_vendor' => 'Slet sælger',
    'view_vendor' => 'Vis sælger',
    'deleted_expense' => 'Successfully deleted expense',
    'archived_expense' => 'Successfully archived expense',
    'deleted_expenses' => 'Successfully deleted expenses',
    'archived_expenses' => 'Successfully archived expenses',
    'expense_amount' => 'Expense Amount',
    'expense_balance' => 'Expense Balance',
    'expense_date' => 'Expense Date',
    'expense_should_be_invoiced' => 'Should this expense be invoiced?',
    'public_notes' => 'Public Notes',
    'invoice_amount' => 'Invoice Amount',
    'exchange_rate' => 'Exchange Rate',
    'yes' => 'Yes',
    'no' => 'No',
    'should_be_invoiced' => 'Should be invoiced',
    'view_expense' => 'View expense # :expense',
    'edit_expense' => 'Edit Expense',
    'archive_expense' => 'Archive Expense',
    'delete_expense' => 'Delete Expense',
    'view_expense_num' => 'Expense # :expense',
    'updated_expense' => 'Successfully updated expense',
    'created_expense' => 'Successfully created expense',
    'enter_expense' => 'Enter Expense',
    'view' => 'View',
    'restore_expense' => 'Restore Expense',
    'invoice_expense' => 'Invoice Expense',
    'expense_error_multiple_clients' => 'The expenses can\'t belong to different clients',
    'expense_error_invoiced' => 'Expense has already been invoiced',
    'convert_currency' => 'Convert currency',
    'num_days' => 'Antal dage',
    'create_payment_term' => 'Create Payment Term',
    'edit_payment_terms' => 'Edit Payment Term',
    'edit_payment_term' => 'Edit Payment Term',
    'archive_payment_term' => 'Archive Payment Term',
    'recurring_due_dates' => 'Recurring Invoice Due Dates',
    'recurring_due_date_help' => '<p>Automatically sets a due date for the invoice.</p>
        <p>Invoices on a monthly or yearly cycle set to be due on or before the day they are created will be due the next month. Invoices set to be due on the 29th or 30th in months that don\'t have that day will be due the last day of the month.</p>
        <p>Invoices on a weekly cycle set to be due on the day of the week they are created will be due the next week.</p>
        <p>For example:</p>
        <ul>
          <li>Today is the 15th, due date is 1st of the month. The due date should likely be the 1st of the next month.</li>
          <li>Today is the 15th, due date is the last day of the month. The due date will be the last day of the this month.
    </li>
          <li>Today is the 15th, due date is the 15th day of the month. The due date will be the 15th day of <strong>next</strong> month.
    </li>
          <li>Today is the Friday, due date is the 1st Friday after. The due date will be next Friday, not today.
    </li>
        </ul>',
    'due' => 'Due',
    'next_due_on' => 'Due Next: :date',
    'use_client_terms' => 'Use client terms',
    'day_of_month' => ':ordinal day of month',
    'last_day_of_month' => 'Last day of month',
    'day_of_week_after' => ':ordinal :day after',
    'sunday' => 'Sunday',
    'monday' => 'Monday',
    'tuesday' => 'Tuesday',
    'wednesday' => 'Wednesday',
    'thursday' => 'Thursday',
    'friday' => 'Friday',
    'saturday' => 'Saturday',
    'header_font_id' => 'Header Font',
    'body_font_id' => 'Body Font',
    'color_font_help' => 'Bemærk: den primære farve og skrifttyper bruges også i klientportalen og brugerdefinerede e-mail-design.',
    'live_preview' => 'Live Preview',
    'invalid_mail_config' => 'Unable to send email, please check that the mail settings are correct.',
    'invoice_message_button' => 'To view your invoice for :amount, click the button below.',
    'quote_message_button' => 'To view your quote for :amount, click the button below.',
    'payment_message_button' => 'Thank you for your payment of :amount.',
    'payment_type_direct_debit' => 'Direct Debit',
    'bank_accounts' => 'Bank Accounts',
    'add_bank_account' => 'Add Bank Account',
    'setup_account' => 'Setup Account',
    'import_expenses' => 'Import Expenses',
    'bank_id' => 'bank',
    'integration_type' => 'Integration Type',
    'updated_bank_account' => 'Successfully updated bank account',
    'edit_bank_account' => 'Edit Bank Account',
    'archive_bank_account' => 'Archive Bank Account',
    'archived_bank_account' => 'Successfully archived bank account',
    'created_bank_account' => 'Successfully created bank account',
    'validate_bank_account' => 'Validate Bank Account',
    'bank_password_help' => 'Note: your password is transmitted securely and never stored on our servers.',
    'bank_password_warning' => 'Advarsel: dit kodeord overføres muligvis i almindelig tekst. Overvej at aktivere HTTPS.',
    'username' => 'Username',
    'account_number' => 'Account Number',
    'account_name' => 'Account Name',
    'bank_account_error' => 'Kunne ikke hente kontooplysninger, du skal kontrollere dine legitimations oplysninger.',
    'status_approved' => 'Godkendt',
    'quote_settings' => 'Quote Settings',
    'auto_convert_quote' => 'Auto konvertering',
    'auto_convert_quote_help' => 'Automatically convert a quote to an invoice when approved by a client.',
    'validate' => 'Validate',
    'info' => 'Info',
    'imported_expenses' => 'Gennemførte oprettelse af :count_vendors sælger(e) og :count_expenses udgifter',
    'iframe_url_help3' => 'Note: if you plan on accepting credit cards details we strongly recommend enabling HTTPS on your site.',
    'expense_error_multiple_currencies' => 'The expenses can\'t have different currencies.',
    'expense_error_mismatch_currencies' => 'The client\'s currency does not match the expense currency.',
    'trello_roadmap' => 'Trello Roadmap',
    'header_footer' => 'Header/Footer',
    'first_page' => 'first page',
    'all_pages' => 'all pages',
    'last_page' => 'last page',
    'all_pages_header' => 'Show header on',
    'all_pages_footer' => 'Show footer on',
    'invoice_currency' => 'Invoice Currency',
    'enable_https' => 'We strongly recommend using HTTPS to accept credit card details online.',
    'quote_issued_to' => 'Quote issued to',
    'show_currency_code' => 'Currency Code',
    'free_year_message' => 'Din konto er opgraderet til pro i et år uden extra omkostninger.',
    'trial_message' => 'Your account will receive a free two week trial of our pro plan.',
    'trial_footer' => 'Din gratis pro plan prøveperiode udløber om :count dage, :link for at opgradere nu.',
    'trial_footer_last_day' => 'Dette er den sidste dag i din gratis pro plan prøveperiode, :link for at opgradere nu.',
    'trial_call_to_action' => 'Start Free Trial',
    'trial_success' => 'Successfully enabled two week free pro plan trial',
    'overdue' => 'Overdue',


    'white_label_text' => 'Køb et ET-ÅRIGT hvidmærket licens til $:price for at fjerne Invoice Ninja-brandingen fra fakturaen og klientportalen.',
    'user_email_footer' => 'For at justere varslings indstillingene besøg venligst :link',
    'reset_password_footer' => 'Hvis du ikke bad om at få nulstillet din adgangskode kontakt venligst kundeservice: :email',
    'limit_users' => 'Desværre, dette vil overstige grænsen på :limit brugere',
    'more_designs_self_host_header' => 'Få 6 flere faktura designs for kun $:price',
    'old_browser' => 'Benyt venligst et :link',
    'newer_browser' => 'nyere browser',
    'white_label_custom_css' => ':link for $:price to enable custom styling and help support our project.',
    'bank_accounts_help' => 'Tilknyt en bankkonto for automatisk import af udgifter og oprettelse af sælgere. Understøtter American Express og :link.',
    'us_banks' => '400+ amerikanske banker',

    'pro_plan_remove_logo' => ':link for at fjerne Invoice Ninja-logoet, opgrader til en Pro Plan',
    'pro_plan_remove_logo_link' => 'Klik her',
    'invitation_status_sent' => 'Sendt',
    'invitation_status_opened' => 'Åbnet',
    'invitation_status_viewed' => 'Set',
    'email_error_inactive_client' => 'Emails can not be sent to inactive clients',
    'email_error_inactive_contact' => 'Emails can not be sent to inactive contacts',
    'email_error_inactive_invoice' => 'Emails can not be sent to inactive invoices',
    'email_error_inactive_proposal' => 'Emails kan ikke sendes til inaktive forslag',
    'email_error_user_unregistered' => 'Please register your account to send emails',
    'email_error_user_unconfirmed' => 'Please confirm your account to send emails',
    'email_error_invalid_contact_email' => 'Invalid contact email',

    'navigation' => 'Navigation',
    'list_invoices' => 'List Invoices',
    'list_clients' => 'List Clients',
    'list_quotes' => 'List Quotes',
    'list_tasks' => 'List Tasks',
    'list_expenses' => 'List Expenses',
    'list_recurring_invoices' => 'List Recurring Invoices',
    'list_payments' => 'List Payments',
    'list_credits' => 'List Credits',
    'tax_name' => 'Tax Name',
    'report_settings' => 'Report Settings',
    'search_hotkey' => 'shortcut is /',

    'new_user' => 'New User',
    'new_product' => 'New Product',
    'new_tax_rate' => 'New Tax Rate',
    'invoiced_amount' => 'Invoiced Amount',
    'invoice_item_fields' => 'Invoice Item Fields',
    'custom_invoice_item_fields_help' => 'Add a field when creating an invoice item and display the label and value on the PDF.',
    'recurring_invoice_number' => 'Tilbagevendende nummer',
    'recurring_invoice_number_prefix_help' => 'Angiv et præfiks som skal tilføjes fakturanummeret for tilbagevendende fakturaer.',

    // Client Passwords
    'enable_portal_password' => 'Adgangskodebeskyttet Fakturaer',
    'enable_portal_password_help' => 'Lader dig indtaste en adgangskode til hver kontakt. Hvis en adgangskode ikke er lavet, vil kontakten blive pålagt at indtaste en adgangskode før det er muligt at se fakturaer.',
    'send_portal_password' => 'Generer automatisk',
    'send_portal_password_help' => 'If no password is set, one will be generated and sent with the first invoice.',

    'expired' => 'Expired',
    'invalid_card_number' => 'The credit card number is not valid.',
    'invalid_expiry' => 'The expiration date is not valid.',
    'invalid_cvv' => 'The CVV is not valid.',
    'cost' => 'Cost',
    'create_invoice_for_sample' => 'Note: create your first invoice to see a preview here.',

    // User Permissions
    'owner' => 'Owner',
    'administrator' => 'Administrator',
    'administrator_help' => 'Allow user to manage users, change settings and modify all records',
    'user_create_all' => 'Create clients, invoices, etc.',
    'user_view_all' => 'View all clients, invoices, etc.',
    'user_edit_all' => 'Edit all clients, invoices, etc.',
    'gateway_help_20' => ':link to sign up for Sage Pay.',
    'gateway_help_21' => ':link to sign up for Sage Pay.',
    'partial_due' => 'Partial Due',
    'restore_vendor' => 'Genskab sælger',
    'restored_vendor' => 'Genskabelse af sælger gennemført',
    'restored_expense' => 'Successfully restored expense',
    'permissions' => 'Permissions',
    'create_all_help' => 'Allow user to create and modify records',
    'view_all_help' => 'Allow user to view records they didn\'t create',
    'edit_all_help' => 'Allow user to modify records they didn\'t create',
    'view_payment' => 'View Payment',

    'january' => 'Januar',
    'february' => 'Februar',
    'march' => 'Marts',
    'april' => 'April',
    'may' => 'Maj',
    'june' => 'Juni',
    'july' => 'Juli',
    'august' => 'August',
    'september' => 'September',
    'october' => 'October',
    'november' => 'November',
    'december' => 'December',

    // Documents
    'documents_header' => 'Documents:',
    'email_documents_header' => 'Documents:',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Final Deliverable.zip',
    'quote_documents' => 'Citer dokumenter',
    'invoice_documents' => 'Faktura dokumenter',
    'expense_documents' => 'Udgift\'s dokumenter',
    'invoice_embed_documents' => 'Embed Documents',
    'invoice_embed_documents_help' => 'Include attached images in the invoice.',
    'document_email_attachment' => 'Attach Documents',
    'ubl_email_attachment' => 'Vedhæft UBL',
    'download_documents' => 'Download Documents (:size)',
    'documents_from_expenses' => 'From Expenses:',
    'dropzone_default_message' => 'Drop files or click to upload',
    'dropzone_default_message_disabled' => 'Uploads er slået fra',
    'dropzone_fallback_message' => 'Your browser does not support drag\'n\'drop file uploads.',
    'dropzone_fallback_text' => 'Please use the fallback form below to upload your files like in the olden days.',
    'dropzone_file_too_big' => 'File is too big ({{filesize}}MiB). Max filesize: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'You can\'t upload files of this type.',
    'dropzone_response_error' => 'Server responded with {{statusCode}} code.',
    'dropzone_cancel_upload' => 'Cancel upload',
    'dropzone_cancel_upload_confirmation' => 'Are you sure you want to cancel this upload?',
    'dropzone_remove_file' => 'Remove file',
    'documents' => 'Documents',
    'document_date' => 'Document Date',
    'document_size' => 'Size',

    'enable_client_portal' => 'Dashboard',
    'enable_client_portal_help' => 'Show/hide the dashboard page in the client portal.',
    'enable_client_portal_dashboard' => 'Dashboard',
    'enable_client_portal_dashboard_help' => 'Show/hide the dashboard page in the client portal.',

    // Plans
    'account_management' => 'Account Management',
    'plan_status' => 'Plan Status',

    'plan_upgrade' => 'Upgrade',
    'plan_change' => 'Change Plan',
    'pending_change_to' => 'Changes To',
    'plan_changes_to' => ':plan on :date',
    'plan_term_changes_to' => ':plan (:term) on :date',
    'cancel_plan_change' => 'Cancel Change',
    'plan' => 'Plan',
    'expires' => 'Expires',
    'renews' => 'Renews',
    'plan_expired' => ':plan Plan Expired',
    'trial_expired' => ':plan Plan Trial Ended',
    'never' => 'Never',
    'plan_free' => 'Free',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Enterprise',
    'plan_white_label' => 'Egen hosting (hvidmærket)',
    'plan_free_self_hosted' => 'Self Hosted (Free)',
    'plan_trial' => 'Trial',
    'plan_term' => 'Term',
    'plan_term_monthly' => 'Monthly',
    'plan_term_yearly' => 'Yearly',
    'plan_term_month' => 'Month',
    'plan_term_year' => 'Year',
    'plan_price_monthly' => '$:price/Month',
    'plan_price_yearly' => '$:price/Year',
    'updated_plan' => 'Updated plan settings',
    'plan_paid' => 'Term Started',
    'plan_started' => 'Plan Started',
    'plan_expires' => 'Plan Expires',

    'white_label_button' => 'Hvidmærke',

    'pro_plan_year_description' => 'One year enrollment in the Invoice Ninja Pro Plan.',
    'pro_plan_month_description' => 'One month enrollment in the Invoice Ninja Pro Plan.',
    'enterprise_plan_product' => 'Enterprise Plan',
    'enterprise_plan_year_description' => 'One year enrollment in the Invoice Ninja Enterprise Plan.',
    'enterprise_plan_month_description' => 'One month enrollment in the Invoice Ninja Enterprise Plan.',
    'plan_credit_product' => 'Credit',
    'plan_credit_description' => 'Credit for unused time',
    'plan_pending_monthly' => 'Will switch to monthly on :date',
    'plan_refunded' => 'A refund has been issued.',

    'live_preview' => 'Live Preview',
    'page_size' => 'Page Size',
    'live_preview_disabled' => 'Live preview has been disabled to support selected font',
    'invoice_number_padding' => 'Padding',
    'preview' => 'Preview',
    'list_vendors' => 'Vis sælgere',
    'add_users_not_supported' => 'Upgrade to the Enterprise plan to add additional users to your account.',
    'enterprise_plan_features' => 'Enterprise-udgaven tilbyder understøttelse af flere brugere og filvedhæftninger, :link for at  se den fulde funktionsoversigt.',
    'return_to_app' => 'Vend tilbage til appen',


    // Payment updates
    'refund_payment' => 'Refunder betaling',
    'refund_max' => 'Max:',
    'refund' => 'Refunder',
    'are_you_sure_refund' => 'Refunder betalinger?',
    'status_pending' => 'Afventer',
    'status_completed' => 'Fuldført',
    'status_failed' => 'Slog fejl',
    'status_partially_refunded' => 'Delst refunderet',
    'status_partially_refunded_amount' => ':amount Refunderet',
    'status_refunded' => 'Refunderet',
    'status_voided' => 'Annulleret',
    'refunded_payment' => 'Refunderet betaling',
    'activity_39' => ':user annullerede en :payment_amount betaling :payment',
    'activity_40' => ':bruger refunderet :justering af en :betaling_beløb betaling :betaling',
    'card_expiration' => 'Exp:&nbsp:expires',

    'card_creditcardother' => 'Ukendt',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Accept Amerikansk bank overførsler',
    'stripe_ach_help' => 'ACH-understøttelse skal også være aktiveret i: link.',
    'ach_disabled' => 'En anden gateway er allerede konfigureret til direkte debitering.',

    'plaid' => 'Betalt',
    'client_id' => 'Klients ID',
    'secret' => 'Hemmelighed',
    'public_key' => 'Offentlig nøgle',
    'plaid_optional' => '(valgfrit)',
    'plaid_environment_help' => 'Når der gives en Stripe-testnøgle, bruges Plaids udviklingsmiljø (tartan).',
    'other_providers' => 'Andre udbydere',
    'country_not_supported' => 'Landet er ikke understøttet.',
    'invalid_routing_number' => 'Routing nummeret er ugyldigt.',
    'invalid_account_number' => 'Kontonummeret er ugyldigt.',
    'account_number_mismatch' => 'Kontonumrene stemmer ikke overens.',
    'missing_account_holder_type' => 'Vælg en individuel eller firmakonto.',
    'missing_account_holder_name' => 'Indtast kontohaverens navn.',
    'routing_number' => 'Routing nummer',
    'confirm_account_number' => 'Bekræft kontonummer',
    'individual_account' => 'Individuel konto',
    'company_account' => 'Firma Konto',
    'account_holder_name' => 'Kontohavers navn',
    'add_account' => 'Tilføj konto',
    'payment_methods' => 'Betalingsmetoder',
    'complete_verification' => 'Komplet verifikation',
    'verification_amount1' => 'Beløb 1',
    'verification_amount2' => 'Beløb 2',
    'payment_method_verified' => 'Verifikation blev gennemført med succes',
    'verification_failed' => 'Verifikation mislykkedes',
    'remove_payment_method' => 'Fjern betalingsmetode',
    'confirm_remove_payment_method' => 'Er du sikker på, at du vil fjerne denne betalingsmetode?',
    'remove' => 'Fjern',
    'payment_method_removed' => 'Fjern betalings middel',
    'bank_account_verification_help' => 'Vi har lavet to indbetalinger til din konto med beskrivelsen "verifikation". Det vil tage 1-2 hverdage før disse indskud vises på dit kontoudtog. Indtast venligst nedenstående beløb.',
    'bank_account_verification_next_steps' => 'Vi har lavet to indbetalinger til din konto med beskrivelsen "verifikation". Det vil tage 1-2 hverdage før disse indskud vises på dit kontoudtog. Når du har beløbene, skal du komme tilbage til denne betalingsmetodeside og klikke på "Gennemfør og afslut verifikation" ved siden af kontoen.',
    'unknown_bank' => 'Ukendt bank',
    'ach_verification_delay_help' => 'Du kan bruge kontoen, når du har gennemført verifikationen. Verifikation tager normalt 1-2 hverdage.',
    'add_credit_card' => 'Tilføj kreditkort',
    'payment_method_added' => 'Tilføjet betalingsmetode',
    'use_for_auto_bill' => 'Brug til automatisk fakturering',
    'used_for_auto_bill' => 'Automatisk faktura betalingsmetode',
    'payment_method_set_as_default' => 'Angiv automatisk fakturerings betalingsmetode.',
    'activity_41' => ':payment_amount betaling (:betaling) mislykkedes',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'Du skal :link.',
    'stripe_webhook_help_link_text' => 'tilføje denne URL som et endepunkt på Stripe',
    'gocardless_webhook_help_link_text' => 'tilføje denne URL som et endepunkt i GoCardless',
    'payment_method_error' => 'Der opstod en fejl ved tilføjelse af din betalingsmetode. Prøv igen senere.',
    'notification_invoice_payment_failed_subject' => 'Betaling mislykkedes for faktura :faktura',
    'notification_invoice_payment_failed' => 'En betaling foretaget af klient :klient mod faktura :faktura mislykkedes. Betalingen er markeret som mislykket, og :beløb er føjet til kundens saldo.',
    'link_with_plaid' => 'Link konto til Plaid med det samme',
    'link_manually' => 'Link manuelt',
    'secured_by_plaid' => 'Sikret af Plaid',
    'plaid_linked_status' => 'Din bankkonto på :bank',
    'add_payment_method' => 'Tilføj betalingsmetode',
    'account_holder_type' => 'Kontoindehaver Type',
    'ach_authorization' => 'Jeg bemyndiger :virksomheden til at bruge min bankkonto til fremtidige betalinger og om nødvendigt elektronisk kreditere min konto for at rette fejlagtige debiteringer. Jeg forstår, at jeg til enhver tid kan annullere denne tilladelse ved at fjerne betalingsmetoden eller ved at kontakte :e-mail.',
    'ach_authorization_required' => 'Du skal godkende ACH-transaktioner.',
    'off' => 'Deaktiver',
    'opt_in' => 'Følg',
    'opt_out' => 'Følg ikke længere',
    'always' => 'Altid',
    'opted_out' => 'Fravalgt(e)',
    'opted_in' => 'Tilmeldt(e)',
    'manage_auto_bill' => 'Administrer automatisk fakturering',
    'enabled' => 'Aktiveret',
    'paypal' => 'Paypal',
    'braintree_enable_paypal' => 'Aktivér PayPal-betalinger via BrainTree',
    'braintree_paypal_disabled_help' => 'PayPal-gateway\'en behandler PayPal-betalinger.',
    'braintree_paypal_help' => 'Du skal også :link.',
    'braintree_paypal_help_link_text' => 'link PayPal til din BrainTree-konto',
    'token_billing_braintree_paypal' => 'Gem betalingsoplysninger',
    'add_paypal_account' => 'Tilføj PayPal-konto',


    'no_payment_method_specified' => 'Der er ikke angivet nogen betalingsmetode',
    'chart_type' => 'Diagramtype',
    'format' => 'Format',
    'import_ofx' => 'Import OFX',
    'ofx_file' => 'OFX Fil',
    'ofx_parse_failed' => 'Kunne ikke analysere OFX-filen',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Tilmeld dig til WePay',
    'use_another_provider' => 'Brug en anden udbyder',
    'company_name' => 'Firma navn',
    'wepay_company_name_help' => 'Dette vises på kundens kreditkortopgørelser.',
    'wepay_description_help' => 'Formålet med denne konto.',
    'wepay_tos_agree' => 'Jeg accepterer :linket.',
    'wepay_tos_link_text' => 'WePay servicevilkår',
    'resend_confirmation_email' => 'Gensend bekræftelses e-mail',
    'manage_account' => 'Administrer konto',
    'action_required' => 'Handling krævet',
    'finish_setup' => 'Afslut installationen',
    'created_wepay_confirmation_required' => 'Kontroller din e-mail og bekræft din e-mail-adresse med WePay.',
    'switch_to_wepay' => 'Skift til WePay',
    'switch' => 'Skift',
    'restore_account_gateway' => 'Genskab gateway',
    'restored_account_gateway' => 'Gateway blev genskabt',
    'united_states' => 'USA',
    'canada' => 'Canada',
    'accept_debit_cards' => 'Accepter betalingskort',
    'debit_cards' => 'Debetkort',

    'warn_start_date_changed' => 'Den næste faktura sendes på den nye startdato.',
    'warn_start_date_changed_not_sent' => 'Den næste faktura oprettes på den nye startdato.',
    'original_start_date' => 'Original startdato',
    'new_start_date' => 'Ny startdato',
    'security' => 'Sikkerhed',
    'see_whats_new' => 'Se hvad der er nyt i v:version',
    'wait_for_upload' => 'Vent til dokument upload er helt afsluttet.',
    'upgrade_for_permissions' => 'Opgrader til vores Enterprise plan for at aktivere tilladelser.',
    'enable_second_tax_rate' => 'Aktivér angivelse af <b>anden skattesats</b>',
    'payment_file' => 'Betalings fil',
    'expense_file' => 'Udgifts fil',
    'product_file' => 'Produkt fil',
    'import_products' => 'Importer produkter',
    'products_will_create' => 'Produkter vil blive oprettet',
    'product_key' => 'Produkt',
    'created_products' => 'Oprettet / opdateret med succes :tæl produkt(er)',
    'export_help' => 'Brug JSON, hvis du planlægger at importere dataene til Invoice Ninja.<br/>Filen inkluderer klienter, produkter, fakturaer, tilbud og betalinger.',
    'selfhost_export_help' => '<br/>Vi anbefaler at bruge mysqldump til at oprette en fuld sikkerhedskopi.',
    'JSON_file' => 'JSON Fil',

    'view_dashboard' => 'Oversigt',
    'client_session_expired' => 'Session er udløbet.',
    'client_session_expired_message' => 'Din session er udløbet. Klik på linket i din e-mail igen.',

    'auto_bill_notification' => 'Denne faktura faktureres automatisk til din valgte :Payment_method den :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'Bankkonto',
    'auto_bill_payment_method_credit_card' => 'Kredit kort',
    'auto_bill_payment_method_paypal' => 'PayPal konto',
    'auto_bill_notification_placeholder' => 'Denne faktura vil automatisk trække fra dit gemte kreditkort på den forfaldne dato.',
    'payment_settings' => 'Betalingsindstillinger',

    'on_send_date' => 'På sendedato',
    'on_due_date' => 'Betalingsfrist',
    'auto_bill_ach_date_help' => 'ACH fakturerer altid til den forfaldne dato.',
    'warn_change_auto_bill' => 'På grund af NACHA-regler kan ændringer af denne faktura forhindre ACH-autofaktura.',

    'bank_account' => 'Bankkonto',
    'payment_processed_through_wepay' => 'ACH-betalinger behandles med WePay.',
    'wepay_payment_tos_agree' => 'Jeg accepterer WePay :vilkår og :privacy_policy.',
    'privacy_policy' => 'Privatlivspolitik',
    'wepay_payment_tos_agree_required' => 'Du skal acceptere WePays Servicevilkår og Privatlivspolitik.',
    'ach_email_prompt' => 'Indtast venligst din e-mail adresse:',
    'verification_pending' => 'Afventer bekræftelse',

    'update_font_cache' => 'Indlæs venligst siden igen for at opdatere font cachen.',
    'more_options' => 'Flere muligheder',
    'credit_card' => 'Kreditkort',
    'bank_transfer' => 'Bankoverførsel',
    'no_transaction_reference' => 'Vi modtog ikke en reference for betalingstransaktionen fra gateway\'en.',
    'use_bank_on_file' => 'Brug bank info',
    'auto_bill_email_message' => 'Fakturaen bliver automatisk betalt via den registrerede betalings metode på forfaldsdagen.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Tilføjet :date',
    'failed_remove_payment_method' => 'Det lykkedes ikke at fjerne betalingsmetoden',
    'gateway_exists' => 'Denne gateway eksisterer allerede',
    'manual_entry' => 'Manuel indtastning',
    'start_of_week' => 'Første dag i ugen',

    // Frequencies
    'freq_inactive' => 'Inaktiv',
    'freq_daily' => 'Daglig',
    'freq_weekly' => 'Ugentlig',
    'freq_biweekly' => 'Hver 14. dag',
    'freq_two_weeks' => 'To uger',
    'freq_four_weeks' => 'Fire uger',
    'freq_monthly' => 'Månedlig',
    'freq_three_months' => 'Tre måneder',
    'freq_four_months' => 'Fire måneder',
    'freq_six_months' => 'Seks måneder',
    'freq_annually' => 'Årlig',
    'freq_two_years' => 'To år',

    // Payment types
    'payment_type_Apply Credit' => 'Tilføj kredit',
    'payment_type_Bank Transfer' => 'Bankoverførsel',
    'payment_type_Cash' => 'Kontant',
    'payment_type_Debit' => 'Debit',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visa Kort',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover Card',
    'payment_type_Diners Card' => 'Diners Card',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Kreditkort Andet',
    'payment_type_PayPal' => 'Paypal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Check',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Direct Debit',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Regnskab og jura',
    'industry_Advertising' => 'Annoncering',
    'industry_Aerospace' => 'Rumfart',
    'industry_Agriculture' => 'Landbrug',
    'industry_Automotive' => 'Autobranche',
    'industry_Banking & Finance' => 'Bank og finans',
    'industry_Biotechnology' => 'Bioteknologi',
    'industry_Broadcasting' => 'Radio- og tv udsendelser',
    'industry_Business Services' => 'Forretningsservice',
    'industry_Commodities & Chemicals' => 'Råvarer og kemikalier',
    'industry_Communications' => 'Kommunikation',
    'industry_Computers & Hightech' => 'Computere og Højteknologi',
    'industry_Defense' => 'Forsvaret',
    'industry_Energy' => 'Energi',
    'industry_Entertainment' => 'Underholdning',
    'industry_Government' => 'Regering',
    'industry_Healthcare & Life Sciences' => 'Healthcare & Life Sciences',
    'industry_Insurance' => 'Forsikring',
    'industry_Manufacturing' => 'Produktion',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Medier',
    'industry_Nonprofit & Higher Ed' => 'Nonprofit',
    'industry_Pharmaceuticals' => 'Medicinal',
    'industry_Professional Services & Consulting' => 'Professionelle serviceydelser og rådgivning',
    'industry_Real Estate' => 'Fast ejendom',
    'industry_Restaurant & Catering' => 'Restaurant og catering',
    'industry_Retail & Wholesale' => 'Detailhandel og engros',
    'industry_Sports' => 'Sport',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Rejser & luksus',
    'industry_Other' => 'Andet',
    'industry_Photography' => 'Fotografi',

    // Countries
    'country_Afghanistan' => 'Afghanistan',
    'country_Albania' => 'Albanien',
    'country_Antarctica' => 'Antarctica',
    'country_Algeria' => 'Algeriet',
    'country_American Samoa' => 'American Samoa',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua og Barbuda',
    'country_Azerbaijan' => 'Azerbaijan',
    'country_Argentina' => 'Argentina',
    'country_Australia' => 'Australien',
    'country_Austria' => 'Østrig',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahrain',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Armenia',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Belgien',
    'country_Bermuda' => 'Bermuda',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Bolivia, Plurinational State of',
    'country_Bosnia and Herzegovina' => 'Bosnia og Herzegovina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Bouvet Island',
    'country_Brazil' => 'Brazilien',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'British Indian Ocean Territory',
    'country_Solomon Islands' => 'Solomon Islands',
    'country_Virgin Islands, British' => 'Virgin Islands, British',
    'country_Brunei Darussalam' => 'Brunei Darussalam',
    'country_Bulgaria' => 'Bulgarien',
    'country_Myanmar' => 'Myanmar',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Hviderusland',
    'country_Cambodia' => 'Cambodia',
    'country_Cameroon' => 'Cameroon',
    'country_Canada' => 'Canada',
    'country_Cape Verde' => 'Cape Verde',
    'country_Cayman Islands' => 'Cayman Islands',
    'country_Central African Republic' => 'Central African Republic',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Chad',
    'country_Chile' => 'Chile',
    'country_China' => 'Kina',
    'country_Taiwan, Province of China' => 'Taiwan',
    'country_Christmas Island' => 'Christmas Island',
    'country_Cocos (Keeling) Islands' => 'Cocos (Keeling) Islands',
    'country_Colombia' => 'Colombia',
    'country_Comoros' => 'Comoros',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Congo',
    'country_Congo, the Democratic Republic of the' => 'Congo, the Democratic Republic of the',
    'country_Cook Islands' => 'Cook Islands',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Kroatien',
    'country_Cuba' => 'Cuba',
    'country_Cyprus' => 'Cypern',
    'country_Czech Republic' => 'Tjekkiet',
    'country_Benin' => 'Benin',
    'country_Denmark' => 'Danmark',
    'country_Dominica' => 'Dominica',
    'country_Dominican Republic' => 'Dominican Republic',
    'country_Ecuador' => 'Ecuador',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Equatorial Guinea',
    'country_Ethiopia' => 'Etiopien',
    'country_Eritrea' => 'Eritrea',
    'country_Estonia' => 'Estland',
    'country_Faroe Islands' => 'Færøerne',
    'country_Falkland Islands (Malvinas)' => 'Falkland Islands (Maldiverne)',
    'country_South Georgia and the South Sandwich Islands' => 'South Georgia og South Sandwich Islands',
    'country_Fiji' => 'Fiji',
    'country_Finland' => 'Finland',
    'country_Åland Islands' => 'Åland Islands',
    'country_France' => 'Frankrig',
    'country_French Guiana' => 'French Guiana',
    'country_French Polynesia' => 'French Polynesia',
    'country_French Southern Territories' => 'French Southern Territories',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Georgien',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => 'Palestinian Territory, Occupied',
    'country_Germany' => 'Tyskland',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Grækenland',
    'country_Greenland' => 'Grønland',
    'country_Grenada' => 'Grenada',
    'country_Guadeloupe' => 'Guadeloupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinea',
    'country_Guyana' => 'Guyana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Heard Island and McDonald Islands',
    'country_Holy See (Vatican City State)' => 'Holy See (Vatican City State)',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Ungarn',
    'country_Iceland' => 'Island',
    'country_India' => 'Indien',
    'country_Indonesia' => 'Indonesien',
    'country_Iran, Islamic Republic of' => 'Iran',
    'country_Iraq' => 'Irak',
    'country_Ireland' => 'Irland',
    'country_Israel' => 'Israel',
    'country_Italy' => 'Italien',
    'country_Côte d\'Ivoire' => 'Côte d\'Ivoire',
    'country_Jamaica' => 'Jamaica',
    'country_Japan' => 'Japan',
    'country_Kazakhstan' => 'Kazakhstan',
    'country_Jordan' => 'Jordan',
    'country_Kenya' => 'Kenya',
    'country_Korea, Democratic People\'s Republic of' => 'Korea',
    'country_Korea, Republic of' => 'Korea',
    'country_Kuwait' => 'Kuwait',
    'country_Kyrgyzstan' => 'Kyrgyzstan',
    'country_Lao People\'s Democratic Republic' => 'Lao',
    'country_Lebanon' => 'Lebanon',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Letland',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Liberien',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Litauen',
    'country_Luxembourg' => 'Luxembourg',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malaysia',
    'country_Maldives' => 'Maldives',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauritania',
    'country_Mauritius' => 'Mauritius',
    'country_Mexico' => 'Mexico',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolia',
    'country_Moldova, Republic of' => 'Moldova, Republic of',
    'country_Montenegro' => 'Montenegro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Morocco',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibia',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Holland',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten (Holland)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius and Saba',
    'country_New Caledonia' => 'New Caledonia',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'New Zealand',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolk Island',
    'country_Norway' => 'Norge',
    'country_Northern Mariana Islands' => 'Northern Mariana Islands',
    'country_United States Minor Outlying Islands' => 'US Minor Outlying Islands',
    'country_Micronesia, Federated States of' => 'Micronesia, Federated States of',
    'country_Marshall Islands' => 'Marshall Islands',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papua Ny Guinea',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Filippinerne',
    'country_Pitcairn' => 'Pitcairn',
    'country_Poland' => 'Polen',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guinea-Bissau',
    'country_Timor-Leste' => 'Timor-Leste',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Qatar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Rumænien',
    'country_Russian Federation' => 'Rusland',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension and Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint Kitts and Nevis',
    'country_Anguilla' => 'Angola',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin (Frankrig)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre and Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent and the Grenadines',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tome and Principe',
    'country_Saudi Arabia' => 'Saudi Arabien',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Serbien',
    'country_Seychelles' => 'Seychellerne',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapore',
    'country_Slovakia' => 'Slovakiet',
    'country_Viet Nam' => 'Vietnam',
    'country_Slovenia' => 'Slovenien',
    'country_Somalia' => 'Somalia',
    'country_South Africa' => 'Syd Afrika',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'Spanien',
    'country_South Sudan' => 'Syd Sudan',
    'country_Sudan' => 'Sudan',
    'country_Western Sahara' => 'Vestlige Sahara',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard og Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Sverige',
    'country_Switzerland' => 'Schweiz',
    'country_Syrian Arab Republic' => 'Syrian Arab Republic',
    'country_Tajikistan' => 'Tajikistan',
    'country_Thailand' => 'Thailand',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad og Tobago',
    'country_United Arab Emirates' => 'Forenede Arabiske Emirater',
    'country_Tunisia' => 'Tunesien',
    'country_Turkey' => 'Tyrkiet',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks og Caicosøerne',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ukraine',
    'country_Macedonia, the former Yugoslav Republic of' => 'Makedonien, Den Tidligere Jugoslaviske Republik',
    'country_Egypt' => 'Egypten',
    'country_United Kingdom' => 'England',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Isle of Man',
    'country_Tanzania, United Republic of' => 'Tanzania, United Republic of',
    'country_United States' => 'USA',
    'country_Virgin Islands, U.S.' => 'Virgin Islands, U.S.',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Uzbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela, Bolivarian Republic of',
    'country_Wallis and Futuna' => 'Wallis and Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Yemen',
    'country_Zambia' => 'Zambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Brazilian Portuguese',
    'lang_Croatian' => 'Kroatisk',
    'lang_Czech' => 'Tjekkisk',
    'lang_Danish' => 'Dansk',
    'lang_Dutch' => 'Hollandsk',
    'lang_English' => 'Engelsk',
    'lang_French' => 'Fransk',
    'lang_French - Canada' => 'Fransk - Canadisk',
    'lang_German' => 'Tysk',
    'lang_Italian' => 'Italiensk',
    'lang_Japanese' => 'Japansk',
    'lang_Lithuanian' => 'Litauisk',
    'lang_Norwegian' => 'Norsk',
    'lang_Polish' => 'Polsk',
    'lang_Spanish' => 'Spansk',
    'lang_Spanish - Spain' => 'Spansk - Spanien',
    'lang_Swedish' => 'Svensk',
    'lang_Albanian' => 'Albansk',
    'lang_Greek' => 'Græsk',
    'lang_English - United Kingdom' => 'Engelsk - England',
    'lang_English - Australia' => 'Engelsk - Australia',
    'lang_Slovenian' => 'Slovensk',
    'lang_Finnish' => 'Finsk',
    'lang_Romanian' => 'Rumænsk',
    'lang_Turkish - Turkey' => 'Tyrkisk',
    'lang_Portuguese - Brazilian' => 'Portugisisk - Brazilien',
    'lang_Portuguese - Portugal' => 'Portugisisk - Portugal',
    'lang_Thai' => 'Thai',
    'lang_Macedonian' => 'Makedonien',
    'lang_Chinese - Taiwan' => 'Kinesisk - Taiwan',
    'lang_Serbian' => 'Serbisk',
    'lang_Bulgarian' => 'Bulgarsk',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Regnskab og jura',
    'industry_Advertising' => 'Annoncering',
    'industry_Aerospace' => 'Rumfart',
    'industry_Agriculture' => 'Landbrug',
    'industry_Automotive' => 'Autobranche',
    'industry_Banking & Finance' => 'Bank og finans',
    'industry_Biotechnology' => 'Bioteknologi',
    'industry_Broadcasting' => 'Radio- og tv udsendelser',
    'industry_Business Services' => 'Forretningsservice',
    'industry_Commodities & Chemicals' => 'Råvarer og kemikalier',
    'industry_Communications' => 'Kommunikation',
    'industry_Computers & Hightech' => 'Computere og Højteknologi',
    'industry_Defense' => 'Forsvaret',
    'industry_Energy' => 'Energi',
    'industry_Entertainment' => 'Underholdning',
    'industry_Government' => 'Regering',
    'industry_Healthcare & Life Sciences' => 'Healthcare & Life Sciences',
    'industry_Insurance' => 'Forsikring',
    'industry_Manufacturing' => 'Produktion',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Medier',
    'industry_Nonprofit & Higher Ed' => 'Nonprofit',
    'industry_Pharmaceuticals' => 'Medicinal',
    'industry_Professional Services & Consulting' => 'Professionelle serviceydelser og rådgivning',
    'industry_Real Estate' => 'Fast ejendom',
    'industry_Retail & Wholesale' => 'Detailhandel og engros',
    'industry_Sports' => 'Sport',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Rejser & luksus',
    'industry_Other' => 'Andet',
    'industry_Photography' => 'Fotografi',

    'view_client_portal' => 'Se kundeportal',
    'view_portal' => 'Se Portal',
    'vendor_contacts' => 'Salgskontakter',
    'all' => 'Alle',
    'selected' => 'Valgt',
    'category' => 'Kategori',
    'categories' => 'Kategorier',
    'new_expense_category' => 'Ny udgiftskategori',
    'edit_category' => 'Rediger kategori',
    'archive_expense_category' => 'Arkiver kategori',
    'expense_categories' => 'Udgiftskategorier',
    'list_expense_categories' => 'Udgiftskategoriliste',
    'updated_expense_category' => 'Ajourført udgiftskategori',
    'created_expense_category' => 'Udgiftskategori oprettet',
    'archived_expense_category' => 'Udgiftskategori arkiveret',
    'archived_expense_categories' => '.count udgiftskategori(er) arkiveret ',
    'restore_expense_category' => 'Genopret udgiftskategori',
    'restored_expense_category' => 'Udgiftskategori genoprettet',
    'apply_taxes' => 'Tilføj moms',
    'min_to_max_users' => ':min til :max brugere',
    'max_users_reached' => 'Det maksimale antal brugere er nået.',
    'buy_now_buttons' => '"Køb nu" knapper',
    'landing_page' => 'Landingsside',
    'payment_type' => 'Betalingstype',
    'form' => 'Formular',
    'link' => 'Link',
    'fields' => 'Felter',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Bemærk: Kunden og fakturaen bliver oprettet, også selvom transaktionen ikke gennemføres.',
    'buy_now_buttons_disabled' => 'Denne funktion kræver, at et produkt oprettes og en betalingsgateway er konfigureret.',
    'enable_buy_now_buttons_help' => 'Aktiver understøttelse af "Køb nu" knapper',
    'changes_take_effect_immediately' => 'Bemærk: Ændringer slår igennem med det samme',
    'wepay_account_description' => 'Betalingsgateway til Invoice Ninja',
    'payment_error_code' => 'Der opstod en fejl i forbindelse med betalingen [:code]. Prøv igen senere.',
    'standard_fees_apply' => 'Gebyr: 2,9%/1,2% [Credit Card/Bank Transfer] + 2 DKK pr. gennemført transaktion.',
    'limit_import_rows' => 'Data skal importeres samlet i :count rækker eller færre',
    'error_title' => 'Noget gik galt',
    'error_contact_text' => 'Hvis du ønsker hjælp, send venligst en e-mail til :mailaddress',
    'no_undo' => 'Advarsel: Dette kan ikke fortrydes.',
    'no_contact_selected' => 'Vælg venligst en kontakt',
    'no_client_selected' => 'Vælg venligst en kunde',

    'gateway_config_error' => 'Det kan måske hjælpe at ændre kodeord eller generere nye API nøgler.',
    'payment_type_on_file' => 'Gemt :type',
    'invoice_for_client' => 'Faktura :invoice til :client',
    'intent_not_found' => 'Beklager, jeg er ikke sikker på jeg forstår, hvad du spørger om?',
    'intent_not_supported' => 'Beklager, jeg kan ikke gøre det.',
    'client_not_found' => 'Jeg kunne ikke finde kunden',
    'not_allowed' => 'Beklager, du har ikke de nødvendige tilladelser',
    'bot_emailed_invoice' => 'Din faktura er blevet sendt.',
    'bot_emailed_notify_viewed' => 'Jeg sender dig en e-mail når den er læst',
    'bot_emailed_notify_paid' => 'Jeg sender dig en e-mail, når den er betalt',
    'add_product_to_invoice' => 'Tilføj 1 :product',
    'not_authorized' => 'Du er ikke autoriseret',
    'bot_get_email' => 'Hej!<br/>Tak, fordi du prøvede Invoice Ninja Bot.<br/>Du skal oprette en gratis konto for at bruge denne bot.<br/>Send mig din e-mail-adresse til din konto for at komme i gang.',
    'bot_get_code' => 'Tak! Jeg har sendt dig en e-mail med din sikkerhedskode.',
    'bot_welcome' => 'Det er det, din konto er verificeret.<br/>',
    'email_not_found' => 'Jeg kunne ikke finde en tilgængelig konto til :e-mail',
    'invalid_code' => 'Koden er ikke korrekt',
    'security_code_email_subject' => 'Sikkerhedskode til Invoice Ninja Bot',
    'security_code_email_line1' => 'Dette er din Invoice Ninja Bot sikkerhedskode.',
    'security_code_email_line2' => 'Bemærk: den udløber om 10 minutter.',
    'bot_help_message' => 'Jeg understøtter i øjeblikket:<br/>• Opret \ opdater \ e-mail en faktura<br/>• Vis produkter<br/>For eksempel:<br/><i>fakturerer bob for 2 billetter, indstil forfaldsdato til næste torsdag og rabatten til 10 procent</i>',
    'list_products' => 'Liste over produkter',

    'include_item_taxes_inline' => 'Inkluder<b>linjepost skatter i linjen i alt</b>',
    'created_quotes' => 'Oprettelse vellykket :tæl tilbud',
    'limited_gateways' => 'Bemærk: vi understøtter én kreditkortgateway per virksomhed.',

    'warning' => 'Advarsel',
    'self-update' => 'Opdatér',
    'update_invoiceninja_title' => 'Opdatér Invoice Ninja',
    'update_invoiceninja_warning' => 'Før du starter opgraderingen af Invoice Ninja, opret en sikkerhedskopi af din database og filer!',
    'update_invoiceninja_available' => 'En ny version af Invoice Ninja er tilgængelig.',
    'update_invoiceninja_unavailable' => 'Der er ingen ny version af Invoice Ninja tilgængelig.',
    'update_invoiceninja_instructions' => 'Installér venligst den nyeste version <strong>:version</strong> ved at klikke på knappen <em>Opdatér nu</em> nedenfor. Efterfølgende vil du blive dirigeret til oversigten.',
    'update_invoiceninja_update_start' => 'Opdatér nu',
    'update_invoiceninja_download_start' => 'Download :version',
    'create_new' => 'Opret ny',

    'toggle_navigation' => 'Skift navigation',
    'toggle_history' => 'Skift historie',
    'unassigned' => 'Ikke tilknyttet',
    'task' => 'Opgave',
    'contact_name' => 'Kontakt navn',
    'city_state_postal' => 'By/Postnummer',
    'custom_field' => 'Brugerdefineret felt',
    'account_fields' => 'Virksomheds felter',
    'facebook_and_twitter' => 'Facebook og Twitter',
    'facebook_and_twitter_help' => 'Følg vores feeds for at hjælpe med at støtte vores projekt',
    'reseller_text' => 'Bemærk: Et hvidmærket licens er beregnet til personlig brug, så send en e-mail til os på :email, hvis du gerne vil videresælge appen.',
    'unnamed_client' => 'Ukendt klient',

    'day' => 'Dag',
    'week' => 'Uge',
    'month' => 'Måned',
    'inactive_logout' => 'Du er blevet logget ud på grund af inaktivitet..',
    'reports' => 'Rapporter',
    'total_profit' => 'Profit total',
    'total_expenses' => 'Udgifter total',
    'quote_to' => 'Tilbud til',

    // Limits
    'limit' => 'Grænse',
    'min_limit' => 'Min: :min',
    'max_limit' => 'Max: :max',
    'no_limit' => 'Ingen grænse',
    'set_limits' => 'Sæt :gateway_type Limits',
    'enable_min' => 'Aktivér minimum',
    'enable_max' => 'Aktivér maksimum',
    'min' => 'Min',
    'max' => 'Max',
    'limits_not_met' => 'Denne faktura overholder ikke grænserne for den betalingstype.',

    'date_range' => 'Dato område',
    'raw' => 'Rå',
    'raw_html' => 'Rå HTML',
    'update' => 'Opdatér',
    'invoice_fields_help' => 'Træk og slip felter for at ændre deres rækkefølge og placering',
    'new_category' => 'Ny kategori',
    'restore_product' => 'Gendan produkt',
    'blank' => 'Blank',
    'invoice_save_error' => 'Der opstod en fejl ved lagring af din faktura',
    'enable_recurring' => 'Aktivér tilbagevendende',
    'disable_recurring' => 'Deaktiver tilbagevendende',
    'text' => 'Tekst',
    'expense_will_create' => 'udgifter oprettes',
    'expenses_will_create' => 'udgifter oprettes',
    'created_expenses' => 'Oprettet :tæl udgifter',

    'translate_app' => 'Hjælp med at forbedre vores oversættelser med :link',
    'expense_category' => 'Udgiftskategori',

    'go_ninja_pro' => 'Gå Ninja Pro!',
    'go_enterprise' => 'Go Enterprise!',
    'upgrade_for_features' => 'Opgrader for adgang til flere funktioner',
    'pay_annually_discount' => 'Betal årligt i 10 måneder + 2 gratis!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'YourBrand.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Tilpas alle aspekter af din faktura!',
    'enterprise_upgrade_feature1' => 'Angiv tilladelser for flere brugere',
    'enterprise_upgrade_feature2' => 'Vedhæft filer fra tredjepart til fakturaer og udgifter',
    'much_more' => 'Meget mere!',
    'all_pro_fetaures' => 'Plus alle pro-funktioner!',

    'currency_symbol' => 'Symbol',
    'currency_code' => 'Kode',

    'buy_license' => 'Køb licens',
    'apply_license' => 'Anvend licens',
    'submit' => 'Indsend',
    'white_label_license_key' => 'Licensnøgle',
    'invalid_white_label_license' => 'Denne hvidmærkede licens er ikke gyldig',
    'created_by' => 'Oprettet af :navn',
    'modules' => 'Moduler',
    'financial_year_start' => 'Årets første måned',
    'authentication' => 'Godkendelse',
    'checkbox' => 'Afkrydsningsfelt',
    'invoice_signature' => 'Underskrift',
    'show_accept_invoice_terms' => 'Afkrydsningsfelt for fakturavilkår',
    'show_accept_invoice_terms_help' => 'Bed kunden om at bekræfte, at de accepterer fakturavilkårene.',
    'show_accept_quote_terms' => 'Tilbuds Betingelser Afkrydsningsfelt',
    'show_accept_quote_terms_help' => 'Bed kunden om at bekræfte, at de accepterer tilbudsbetingelserne.',
    'require_invoice_signature' => 'Fakturasignatur',
    'require_invoice_signature_help' => 'Kræv at klienten giver deres underskrift.',
    'require_quote_signature' => 'Tilbuds underskrift',
    'require_quote_signature_help' => 'Kræv at klienten giver deres underskrift.',
    'i_agree' => 'Jeg accepterer betingelserne',
    'sign_here' => 'Underskriv venligst her (Denne underskrift er juridisk bindende):',
    'authorization' => 'Autorisation',
    'signed' => 'Underskrevet',

    // BlueVine
    'bluevine_promo' => 'Få fleksible forretningsgrænser for kredit- og fakturafakturering ved hjælp af BlueVine.',
    'bluevine_modal_label' => 'Tilmeld dig BlueVine',
    'bluevine_modal_text' => '<h3>Hurtig finansiering til din virksomhed. Intet papirarbejde.</h3>
<ul><li>Fleksible forretningsgrænser for kredit- og fakturafakturering.</li></ul>',
    'bluevine_create_account' => 'Opret en konto',
    'quote_types' => 'Få et tilbud på',
    'invoice_factoring' => 'Fakturafakturering',
    'line_of_credit' => 'Kreditlinje',
    'fico_score' => 'Din FICO-score',
    'business_inception' => 'Begyndelsesdato for virksomhed',
    'average_bank_balance' => 'Gennemsnitlig bankkontosaldo',
    'annual_revenue' => 'Årlig omsætning',
    'desired_credit_limit_factoring' => 'Ønsket faktura faktureringsgrænse',
    'desired_credit_limit_loc' => 'Ønsket kreditgrænse',
    'desired_credit_limit' => 'Ønsket kreditgrænse',
    'bluevine_credit_line_type_required' => 'Du skal vælge mindst en',
    'bluevine_field_required' => 'Dette felt er påkrævet',
    'bluevine_unexpected_error' => 'Der opstod en uventet fejl.',
    'bluevine_no_conditional_offer' => 'Mere information er påkrævet, før du får et tilbud. Klik på fortsæt nedenfor.',
    'bluevine_invoice_factoring' => 'Faktura salg',
    'bluevine_conditional_offer' => 'Betinget tilbud',
    'bluevine_credit_line_amount' => 'Kreditgrænse',
    'bluevine_advance_rate' => 'Forskud',
    'bluevine_weekly_discount_rate' => 'Ugentlig diskonteringsrente',
    'bluevine_minimum_fee_rate' => 'Minimumsgebyr',
    'bluevine_line_of_credit' => 'Kreditgrænse',
    'bluevine_interest_rate' => 'Rentesats',
    'bluevine_weekly_draw_rate' => 'Ugentlig trækprocent',
    'bluevine_continue' => 'Fortsæt til BlueVine',
    'bluevine_completed' => 'Gennemførte tilmelding til BlueVine',

    'vendor_name' => 'Sælger',
    'entity_state' => 'State',
    'client_created_at' => 'Oprettelsesdato',
    'postmark_error' => 'Der var et problem med afsendelse af e-mailen gennem Postmark: :link',
    'project' => 'Projekt',
    'projects' => 'Projekter',
    'new_project' => 'Nyt projekt',
    'edit_project' => 'Redigér projekt',
    'archive_project' => 'Arkivér projekt',
    'list_projects' => 'Vis projekter',
    'updated_project' => 'Projektet blev opdateret',
    'created_project' => 'Projektet blev oprettet',
    'archived_project' => 'Projektet blev arktiveret',
    'archived_projects' => ':count projekter blev arkiveret',
    'restore_project' => 'Genskab projekt',
    'restored_project' => 'Projektet blev genskabt',
    'delete_project' => 'Slet projekt',
    'deleted_project' => 'Projektet blev slettet',
    'deleted_projects' => ':count projekter blev slettet',
    'delete_expense_category' => 'Slet kategori',
    'deleted_expense_category' => 'Sletning af kategori er gennemført',
    'delete_product' => 'Slet produkt',
    'deleted_product' => 'Sletning af produkt gennemført',
    'deleted_products' => 'Sletning af :count produkter gennemført',
    'restored_product' => 'Genskabelse af produkt gennemført',
    'update_credit' => 'Opdatér kredit',
    'updated_credit' => 'Opdatering af kredit gennemført',
    'edit_credit' => 'Redigér kredit',
    'realtime_preview' => 'Forhåndsvisning i realtime',
    'realtime_preview_help' => 'Opfrisk PDF-forhåndsvisning i realtime på fakturasiden når fakturaer redigeres.<br/>Slå denne fra for at forbedre ydelsen ved redigering af fakturaer.',
    'live_preview_help' => 'Vis livetilstand af PDF-forhåndsvisning på fakturasiden.',
    'force_pdfjs_help' => 'Erstat indbyggede PDF-viewer i :chrome_link og :firefox_link.<br/>Slå denne til hvis din browser automatisk henter PDF\'en.',
    'force_pdfjs' => 'Undgå download',
    'redirect_url' => 'URL for viderestilling',
    'redirect_url_help' => 'Valgfri angivelse af en URL som der viderestilles til, efter en betaling af angivet.',
    'save_draft' => 'Gem kladde',
    'refunded_credit_payment' => 'Refunderet kreditbetaling',
    'keyboard_shortcuts' => 'Tastaturgenveje',
    'toggle_menu' => 'Slå menu til/fra',
    'new_...' => 'Ny ...',
    'list_...' => 'Vis ...',
    'created_at' => 'Oprettelsesdato',
    'contact_us' => 'Kontakt os',
    'user_guide' => 'Brugerguide',
    'promo_message' => 'Upgrade before :expires and get :amount OFF your first year of our Pro or Enterprise packages.',
    'discount_message' => ':amount off expires :expires',
    'mark_paid' => 'Markér som betalt',
    'marked_sent_invoice' => 'Successfully marked invoice sent',
    'marked_sent_invoices' => 'Successfully marked invoices sent',
    'invoice_name' => 'Faktura',
    'product_will_create' => 'product will be created',
    'contact_us_response' => 'Thank you for your message! We\'ll try to respond as soon as possible.',
    'last_7_days' => 'Seneste 7 dage',
    'last_30_days' => 'Seneste 30 dage',
    'this_month' => 'Denne måned',
    'last_month' => 'Forrige måned',
    'current_quarter' => 'Nuværende kvartal',
    'last_quarter' => 'Forrige kvartal',
    'last_year' => 'Forrige år',
    'custom_range' => 'Valgfri periode',
    'url' => 'URL',
    'debug' => 'Fejlsøg',
    'https' => 'HTTPS',
    'require' => 'Påkræv',
    'license_expiring' => 'Bemærk: Dit licens udløber om :count dage, :link for at fornye det.',
    'security_confirmation' => 'Din e-mailadresse er blevet bekræftet.',
    'white_label_expired' => 'Dit hvidmærkede licens er udløbet, overvej venligst at fornye det for at støtte op om vores projekt.',
    'renew_license' => 'Forny licens',
    'iphone_app_message' => 'Overvej at hente vores :link',
    'iphone_app' => 'iPhone-app',
    'android_app' => 'Android-app',
    'logged_in' => 'Logget ind',
    'switch_to_primary' => 'Switch to your primary company (:name) to manage your plan.',
    'inclusive' => 'Inklusiv',
    'exclusive' => 'Eksklusiv',
    'postal_city_state' => 'Postnummer/By/Region',
    'phantomjs_help' => 'I visse tilfælde bruger appen :link_phantom til at danne PDF\'en, installér :link_docs for at danne den lokalt.',
    'phantomjs_local' => 'Anvender lokal PhantomJS',
    'client_number' => 'Klientnummer',
    'client_number_help' => 'Angiv et præfiks eller brug et brugerdefineret mønster til dynamisk angivelse af klientnummer.',
    'next_client_number' => 'Det næste klientnummer er :number.',
    'generated_numbers' => 'Dannede numre',
    'notes_reminder1' => 'Første påmindelse',
    'notes_reminder2' => 'Anden påmindelse',
    'notes_reminder3' => 'Tredje påmindelse',
    'notes_reminder4' => 'Påmindelse',
    'bcc_email' => 'BCC-email',
    'tax_quote' => 'Tax Quote',
    'tax_invoice' => 'Tax Invoice',
    'emailed_invoices' => 'Successfully emailed invoices',
    'emailed_quotes' => 'Successfully emailed quotes',
    'website_url' => 'Website-URL',
    'domain' => 'Domæne',
    'domain_help' => 'Used in the client portal and when sending emails.',
    'domain_help_website' => 'Used when sending emails.',
    'import_invoices' => 'Import Invoices',
    'new_report' => 'Ny rapport',
    'edit_report' => 'Redigér rapport',
    'columns' => 'Kolonner',
    'filters' => 'Filtre',
    'sort_by' => 'Sortér efter',
    'draft' => 'Kladde',
    'unpaid' => 'Ikke betalt',
    'aging' => 'Aging',
    'age' => 'Alder',
    'days' => 'Dage',
    'age_group_0' => '0 - 30 dage',
    'age_group_30' => '30 - 60 dage',
    'age_group_60' => '60 - 90 dage',
    'age_group_90' => '90 - 120 dage',
    'age_group_120' => '120+ dage',
    'invoice_details' => 'Fakturadetaljer',
    'qty' => 'Antal',
    'profit_and_loss' => 'Fortjeneste og tab',
    'revenue' => 'Omsætning',
    'profit' => 'Fortjeneste',
    'group_when_sorted' => 'Group Sort',
    'group_dates_by' => 'Gruppér datoer efter',
    'year' => 'År',
    'view_statement' => 'View Statement',
    'statement' => 'Statement',
    'statement_date' => 'Statement Date',
    'mark_active' => 'Markér som aktiv',
    'send_automatically' => 'Send automatisk',
    'initial_email' => 'Indledende e-mail',
    'invoice_not_emailed' => 'Denne faktura er ikke blevet e-mailet.',
    'quote_not_emailed' => 'Dette pristilbud er ikke blevet e-mailet.',
    'sent_by' => 'Sendt af :user',
    'recipients' => 'Modtagere',
    'save_as_default' => 'Gem som standardvalg',
    'start_of_week_help' => 'Bruges af <b>dato<b>-vælgere',
    'financial_year_start_help' => 'Bruges af <b>dato/tidsperiode<b>-vælgere',
    'reports_help' => 'Tast Shift + Klik for at sortere flere kolonner, Ctrl + Klik for at rydde grupperingen.',
    'this_year' => 'Dette år',

    // Updated login screen
    'ninja_tagline' => 'Opret. Send. Modtag betaling.',
    'login_or_existing' => 'Eller log ind med en tilknyttet konto.',
    'sign_up_now' => 'Tilmeld dig nu',
    'not_a_member_yet' => 'Er du ikke allerede medlem?',
    'login_create_an_account' => 'Opret en konto!',

    // New Client Portal styling
    'invoice_from' => 'Fakturaer fra:',
    'email_alias_message' => 'We require each company to have a unique email address.<br/>Consider using an alias. ie, email+label@example.com',
    'full_name' => 'Full Name',
    'month_year' => 'MONTH/YEAR',
    'valid_thru' => 'Valid\nthru',

    'product_fields' => 'Product Fields',
    'custom_product_fields_help' => 'Add a field when creating a product or invoice and display the label and value on the PDF.',
    'freq_two_months' => 'To måneder',
    'freq_yearly' => 'Årligt',
    'profile' => 'Profil',
    'payment_type_help' => 'Sets the default <b>manual payment type</b>.',
    'industry_Construction' => 'Konstruktion',
    'your_statement' => 'Din erklæring',
    'statement_issued_to' => 'Erklæring udstedt til',
    'statement_to' => 'Erklæring til',
    'customize_options' => 'Tilpas valgmuligheder',
    'created_payment_term' => 'Successfully created payment term',
    'updated_payment_term' => 'Successfully updated payment term',
    'archived_payment_term' => 'Successfully archived payment term',
    'resend_invite' => 'Resend Invitation',
    'credit_created_by' => 'Credit created by payment :transaction_reference',
    'created_payment_and_credit' => 'Successfully created payment and credit',
    'created_payment_and_credit_emailed_client' => 'Successfully created payment and credit, and emailed client',
    'create_project' => 'Opret projekt',
    'create_vendor' => 'Create vendor',
    'create_expense_category' => 'Create category',
    'pro_plan_reports' => ':link to enable reports by joining the Pro Plan',
    'mark_ready' => 'Markér som klar',

    'limits' => 'Grænser',
    'fees' => 'Gebyrer',
    'fee' => 'Gebyr',
    'set_limits_fees' => 'Angiv :gateway_type grænser/gebyrer',
    'fees_tax_help' => 'Enable line item taxes to set the fee tax rates.',
    'fees_sample' => 'The fee for a :amount invoice would be :total.',
    'discount_sample' => 'The discount for a :amount invoice would be :total.',
    'no_fees' => 'Ingen gebyrer',
    'gateway_fees_disclaimer' => 'Advarsel: det er ikke alle stater/gateways til betaling, der tillader tilføjelse af gebyrer, gennemgå venligst lokale lovgivninger/servicebetingelser. ',
    'percent' => 'Procent',
    'location' => 'Placering',
    'line_item' => 'Line Item',
    'surcharge' => 'Surcharge',
    'location_first_surcharge' => 'Enabled - First surcharge',
    'location_second_surcharge' => 'Enabled - Second surcharge',
    'location_line_item' => 'Enabled - Line item',
    'online_payment_surcharge' => 'Online Payment Surcharge',
    'gateway_fees' => 'Gebyrer for gateway',
    'fees_disabled' => 'Gebyrer er slået fra',
    'gateway_fees_help' => 'Automatically add an online payment surcharge/discount.',
    'gateway' => 'Gateway',
    'gateway_fee_change_warning' => 'If there are unpaid invoices with fees they need to be updated manually.',
    'fees_surcharge_help' => 'Customize surcharge :link.',
    'label_and_taxes' => 'label and taxes',
    'billable' => 'Fakturérbar',
    'logo_warning_too_large' => 'Billedfilen er for stor',
    'logo_warning_fileinfo' => 'Advarsel: For at understøtte gifbilleder, så skal PHP-udvidelsen fileinfo være slået til.',
    'logo_warning_invalid' => 'There was a problem reading the image file, please try a different format.',

    'error_refresh_page' => 'An error occurred, please refresh the page and try again.',
    'data' => 'Data',
    'imported_settings' => 'Successfully imported settings',
    'reset_counter' => 'Reset Counter',
    'next_reset' => 'Next Reset',
    'reset_counter_help' => 'Automatically reset the invoice and quote counters.',
    'auto_bill_failed' => 'Auto-billing for invoice :invoice_number failed',
    'online_payment_discount' => 'Online Payment Discount',
    'created_new_company' => 'Successfully created new company',
    'fees_disabled_for_gateway' => 'Fees are disabled for this gateway.',
    'logout_and_delete' => 'Log Out/Delete Account',
    'tax_rate_type_help' => 'Inclusive tax rates adjust the line item cost when selected.<br/>Only exclusive tax rates can be used as a default.',
    'invoice_footer_help' => 'Use $pageNumber and $pageCount to display the page information.',
    'credit_note' => 'Kreditnota',
    'credit_issued_to' => 'Kredit udstedt til',
    'credit_to' => 'Kredit til',
    'your_credit' => 'Din kredit',
    'credit_number' => 'Kreditnummer',
    'create_credit_note' => 'Opret kreditnota',
    'menu' => 'Menu',
    'error_incorrect_gateway_ids' => 'Error: The gateways table has incorrect ids.',
    'purge_data' => 'Purge Data',
    'delete_data' => 'Delete Data',
    'purge_data_help' => 'Permanently delete all data but keep the account and settings.',
    'cancel_account_help' => 'Permanently delete the account along with all data and setting.',
    'purge_successful' => 'Successfully purged company data',
    'forbidden' => 'Forbudt',
    'purge_data_message' => 'Advarsel: Dette vil slette dine data permanent, der er ingen måder at fortryde.',
    'contact_phone' => 'Kontakttelefon',
    'contact_email' => 'E-mailkontakt',
    'reply_to_email' => 'Svar-til e-mail',
    'reply_to_email_help' => 'Angiv svar-til adressen for e-mails til klienter.',
    'bcc_email_help' => 'Inkludér denne adresse privat i e-mails til klienter.',
    'import_complete' => 'Din import blev gennemført med succes.',
    'confirm_account_to_import' => 'Bekræft venligst din konto for at importere data.',
    'import_started' => 'Din import er påbegyndt, vi sender dig en e-mail når den er gennemført.',
    'listening' => 'Lytter...',
    'microphone_help' => 'Say "new invoice for [client]" or "show me [client]\'s archived payments"',
    'voice_commands' => 'Talekommandoer',
    'sample_commands' => 'Sample commands',
    'voice_commands_feedback' => 'We\'re actively working to improve this feature, if there\'s a command you\'d like us to support please email us at :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Money Order',
    'archived_products' => 'Successfully archived :count products',
    'recommend_on' => 'We recommend <b>enabling</b> this setting.',
    'recommend_off' => 'We recommend <b>disabling</b> this setting.',
    'notes_auto_billed' => 'Auto-billed',
    'surcharge_label' => 'Surcharge Label',
    'contact_fields' => 'Contact Fields',
    'custom_contact_fields_help' => 'Add a field when creating a contact and optionally display the label and value on the PDF.',
    'datatable_info' => 'Viser :start til :end af :total',
    'credit_total' => 'Credit Total',
    'mark_billable' => 'Mark billable',
    'billed' => 'Faktureret',
    'company_variables' => 'Company Variables',
    'client_variables' => 'Client Variables',
    'invoice_variables' => 'Invoice Variables',
    'navigation_variables' => 'Navigation Variables',
    'custom_variables' => 'Custom Variables',
    'invalid_file' => 'Invalid file type',
    'add_documents_to_invoice' => 'Add documents to invoice',
    'mark_expense_paid' => 'Markér som betalt',
    'white_label_license_error' => 'Failed to validate the license, check storage/logs/laravel-error.log for more details.',
    'plan_price' => 'Plan Price',
    'wrong_confirmation' => 'Incorrect confirmation code',
    'oauth_taken' => 'The account is already registered',
    'emailed_payment' => 'Successfully emailed payment',
    'email_payment' => 'Email Payment',
    'invoiceplane_import' => 'Use :link to migrate your data from InvoicePlane.',
    'duplicate_expense_warning' => 'Warning: This :link may be a duplicate',
    'expense_link' => 'expense',
    'resume_task' => 'Resume Task',
    'resumed_task' => 'Successfully resumed task',
    'quote_design' => 'Quote Design',
    'default_design' => 'Standarddesign',
    'custom_design1' => 'Brugerdefineret design 1',
    'custom_design2' => 'Brugerdefineret design 2',
    'custom_design3' => 'Brugerdefineret design 3',
    'empty' => 'Empty',
    'load_design' => 'Indlæs design',
    'accepted_card_logos' => 'Accepted Card Logos',
    'phantomjs_local_and_cloud' => 'Using local PhantomJS, falling back to phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Analytics Key',
    'analytics_key_help' => 'Track payments using :link',
    'start_date_required' => 'The start date is required',
    'application_settings' => 'Application Settings',
    'database_connection' => 'Database Connection',
    'driver' => 'Driver',
    'host' => 'Host',
    'database' => 'Database',
    'test_connection' => 'Test connection',
    'from_name' => 'From Name',
    'from_address' => 'From Address',
    'port' => 'Port',
    'encryption' => 'Kryptering',
    'mailgun_domain' => 'Mailgun Domain',
    'mailgun_private_key' => 'Mailgun Private Key',
    'send_test_email' => 'Send test email',
    'select_label' => 'Select Label',
    'label' => 'Label',
    'service' => 'Service',
    'update_payment_details' => 'Update payment details',
    'updated_payment_details' => 'Successfully updated payment details',
    'update_credit_card' => 'Update Credit Card',
    'recurring_expenses' => 'Recurring Expenses',
    'recurring_expense' => 'Recurring Expense',
    'new_recurring_expense' => 'New Recurring Expense',
    'edit_recurring_expense' => 'Edit Recurring Expense',
    'archive_recurring_expense' => 'Archive Recurring Expense',
    'list_recurring_expense' => 'List Recurring Expenses',
    'updated_recurring_expense' => 'Successfully updated recurring expense',
    'created_recurring_expense' => 'Successfully created recurring expense',
    'archived_recurring_expense' => 'Successfully archived recurring expense',
    'restore_recurring_expense' => 'Restore Recurring Expense',
    'restored_recurring_expense' => 'Successfully restored recurring expense',
    'delete_recurring_expense' => 'Delete Recurring Expense',
    'deleted_recurring_expense' => 'Projektet blev slettet',
    'view_recurring_expense' => 'View Recurring Expense',
    'taxes_and_fees' => 'Taxes and fees',
    'import_failed' => 'Import Failed',
    'recurring_prefix' => 'Recurring Prefix',
    'options' => 'Options',
    'credit_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the credit number for negative invoices.',
    'next_credit_number' => 'The next credit number is :number.',
    'padding_help' => 'The number of zero\'s to pad the number.',
    'import_warning_invalid_date' => 'Warning: The date format appears to be invalid.',
    'product_notes' => 'Product Notes',
    'app_version' => 'App Version',
    'ofx_version' => 'OFX Version',
    'gateway_help_23' => ':link to get your Stripe API keys.',
    'error_app_key_set_to_default' => 'Error: APP_KEY is set to a default value, to update it backup your database and then run <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Charge Late Fee',
    'late_fee_amount' => 'Late Fee Amount',
    'late_fee_percent' => 'Late Fee Percent',
    'late_fee_added' => 'Late fee added on :date',
    'download_invoice' => 'Download Invoice',
    'download_quote' => 'Download Quote',
    'invoices_are_attached' => 'Your invoice PDFs are attached.',
    'downloaded_invoice' => 'An email will be sent with the invoice PDF',
    'downloaded_quote' => 'An email will be sent with the quote PDF',
    'downloaded_invoices' => 'An email will be sent with the invoice PDFs',
    'downloaded_quotes' => 'An email will be sent with the quote PDFs',
    'clone_expense' => 'Clone Expense',
    'default_documents' => 'Default Documents',
    'send_email_to_client' => 'Send email til kunden',
    'refund_subject' => 'Refund Processed',
    'refund_body' => 'You have been processed a refund of :amount for invoice :invoice_number.',

    'currency_us_dollar' => 'US Dollar',
    'currency_british_pound' => 'British Pound',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'South African Rand',
    'currency_danish_krone' => 'Dansk Krone',
    'currency_israeli_shekel' => 'Israeli Shekel',
    'currency_swedish_krona' => 'Swedish Krona',
    'currency_kenyan_shilling' => 'Kenyan Shilling',
    'currency_canadian_dollar' => 'Canadian Dollar',
    'currency_philippine_peso' => 'Philippine Peso',
    'currency_indian_rupee' => 'Indian Rupee',
    'currency_australian_dollar' => 'Australian Dollar',
    'currency_singapore_dollar' => 'Singapore Dollar',
    'currency_norske_kroner' => 'Norske Kroner',
    'currency_new_zealand_dollar' => 'New Zealand Dollar',
    'currency_vietnamese_dong' => 'Vietnamese Dong',
    'currency_swiss_franc' => 'Swiss Franc',
    'currency_guatemalan_quetzal' => 'Guatemalan Quetzal',
    'currency_malaysian_ringgit' => 'Malaysian Ringgit',
    'currency_brazilian_real' => 'Brazilian Real',
    'currency_thai_baht' => 'Thai Baht',
    'currency_nigerian_naira' => 'Nigerian Naira',
    'currency_argentine_peso' => 'Argentine Peso',
    'currency_bangladeshi_taka' => 'Bangladeshi Taka',
    'currency_united_arab_emirates_dirham' => 'United Arab Emirates Dirham',
    'currency_hong_kong_dollar' => 'Hong Kong Dollar',
    'currency_indonesian_rupiah' => 'Indonesian Rupiah',
    'currency_mexican_peso' => 'Mexican Peso',
    'currency_egyptian_pound' => 'Egyptian Pound',
    'currency_colombian_peso' => 'Colombian Peso',
    'currency_west_african_franc' => 'West African Franc',
    'currency_chinese_renminbi' => 'Chinese Renminbi',
    'currency_rwandan_franc' => 'Rwandan Franc',
    'currency_tanzanian_shilling' => 'Tanzanian Shilling',
    'currency_netherlands_antillean_guilder' => 'Netherlands Antillean Guilder',
    'currency_trinidad_and_tobago_dollar' => 'Trinidad and Tobago Dollar',
    'currency_east_caribbean_dollar' => 'East Caribbean Dollar',
    'currency_ghanaian_cedi' => 'Ghanaian Cedi',
    'currency_bulgarian_lev' => 'Bulgarian Lev',
    'currency_aruban_florin' => 'Aruban Florin',
    'currency_turkish_lira' => 'Turkish Lira',
    'currency_romanian_new_leu' => 'Romanian New Leu',
    'currency_croatian_kuna' => 'Croatian Kuna',
    'currency_saudi_riyal' => 'Saudi Riyal',
    'currency_japanese_yen' => 'Japanese Yen',
    'currency_maldivian_rufiyaa' => 'Maldivian Rufiyaa',
    'currency_costa_rican_colon' => 'Costa Rican Colón',
    'currency_pakistani_rupee' => 'Pakistani Rupee',
    'currency_polish_zloty' => 'Polish Zloty',
    'currency_sri_lankan_rupee' => 'Sri Lankan Rupee',
    'currency_czech_koruna' => 'Czech Koruna',
    'currency_uruguayan_peso' => 'Uruguayan Peso',
    'currency_namibian_dollar' => 'Namibian Dollar',
    'currency_tunisian_dinar' => 'Tunisian Dinar',
    'currency_russian_ruble' => 'Russian Ruble',
    'currency_mozambican_metical' => 'Mozambican Metical',
    'currency_omani_rial' => 'Omani Rial',
    'currency_ukrainian_hryvnia' => 'Ukrainian Hryvnia',
    'currency_macanese_pataca' => 'Macanese Pataca',
    'currency_taiwan_new_dollar' => 'Taiwan New Dollar',
    'currency_dominican_peso' => 'Dominican Peso',
    'currency_chilean_peso' => 'Chilean Peso',
    'currency_icelandic_krona' => 'Icelandic Króna',
    'currency_papua_new_guinean_kina' => 'Papua New Guinean Kina',
    'currency_jordanian_dinar' => 'Jordanian Dinar',
    'currency_myanmar_kyat' => 'Myanmar Kyat',
    'currency_peruvian_sol' => 'Peruvian Sol',
    'currency_botswana_pula' => 'Botswana Pula',
    'currency_hungarian_forint' => 'Hungarian Forint',
    'currency_ugandan_shilling' => 'Ugandan Shilling',
    'currency_barbadian_dollar' => 'Barbadian Dollar',
    'currency_brunei_dollar' => 'Brunei Dollar',
    'currency_georgian_lari' => 'Georgian Lari',
    'currency_qatari_riyal' => 'Qatari Riyal',
    'currency_honduran_lempira' => 'Honduran Lempira',
    'currency_surinamese_dollar' => 'Surinamese Dollar',
    'currency_bahraini_dinar' => 'Bahraini Dinar',
    'currency_venezuelan_bolivars' => 'Venezuelan Bolivars',
    'currency_south_korean_won' => 'South Korean Won',
    'currency_moroccan_dirham' => 'Moroccan Dirham',
    'currency_jamaican_dollar' => 'Jamaican Dollar',
    'currency_angolan_kwanza' => 'Angolan Kwanza',
    'currency_haitian_gourde' => 'Haitian Gourde',
    'currency_zambian_kwacha' => 'Zambian Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Rupee',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritian Rupee',
    'currency_cape_verdean_escudo' => 'Cape Verdean Escudo',
    'currency_kuwaiti_dinar' => 'Kuwaiti Dinar',
    'currency_algerian_dinar' => 'Algerian Dinar',
    'currency_macedonian_denar' => 'Macedonian Denar',
    'currency_fijian_dollar' => 'Fijian Dollar',
    'currency_bolivian_boliviano' => 'Bolivian Boliviano',
    'currency_albanian_lek' => 'Albanian Lek',
    'currency_serbian_dinar' => 'Serbian Dinar',
    'currency_lebanese_pound' => 'Lebanese Pound',
    'currency_armenian_dram' => 'Armenian Dram',
    'currency_azerbaijan_manat' => 'Azerbaijan Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosnia and Herzegovina Convertible Mark',
    'currency_belarusian_ruble' => 'Belarusian Ruble',
    'currency_moldovan_leu' => 'Moldovan Leu',
    'currency_kazakhstani_tenge' => 'Kazakhstani Tenge',
    'currency_gibraltar_pound' => 'Gibraltar Pound',

    'review_app_help' => 'We hope you\'re enjoying using the app.<br/>If you\'d consider :link we\'d greatly appreciate it!',
    'writing_a_review' => 'writing a review',

    'use_english_version' => 'Make sure to use the English version of the files.<br/>We use the column headers to match the fields.',
    'tax1' => 'First Tax',
    'tax2' => 'Second Tax',
    'fee_help' => 'Gateway fees are the costs charged for access to the financial networks that handle the processing of online payments.',
    'format_export' => 'Exporting format',
    'custom1' => 'First Custom',
    'custom2' => 'Second Custom',
    'contact_first_name' => 'Contact First Name',
    'contact_last_name' => 'Contact Last Name',
    'contact_custom1' => 'Contact First Custom',
    'contact_custom2' => 'Contact Second Custom',
    'currency' => 'Currency',
    'ofx_help' => 'To troubleshoot check for comments on :ofxhome_link and test with :ofxget_link.',
    'comments' => 'comments',

    'item_product' => 'Item Product',
    'item_notes' => 'Item Notes',
    'item_cost' => 'Item Cost',
    'item_quantity' => 'Item Quantity',
    'item_tax_rate' => 'Item Tax Rate',
    'item_tax_name' => 'Item Tax Name',
    'item_tax1' => 'Item Tax1',
    'item_tax2' => 'Item Tax2',

    'delete_company' => 'Delete Company',
    'delete_company_help' => 'Permanently delete the company along with all data and setting.',
    'delete_company_message' => 'Warning: This will permanently delete your company, there is no undo.',

    'applied_discount' => 'The coupon has been applied, the plan price has been reduced by :discount%.',
    'applied_free_year' => 'The coupon has been applied, your account has been upgraded to pro for one year.',

    'contact_us_help' => 'If you\'re reporting an error please include any relevant logs from storage/logs/laravel-error.log',
    'include_errors' => 'Include Errors',
    'include_errors_help' => 'Include :link from storage/logs/laravel-error.log',
    'recent_errors' => 'recent errors',
    'customer' => 'Customer',
    'customers' => 'Customers',
    'created_customer' => 'Successfully created customer',
    'created_customers' => 'Successfully created :count customers',

    'purge_details' => 'The data in your company (:account) has been successfully purged.',
    'deleted_company' => 'Successfully deleted company',
    'deleted_account' => 'Successfully canceled account',
    'deleted_company_details' => 'Your company (:account) has been successfully deleted.',
    'deleted_account_details' => 'Your account (:account) has been successfully deleted.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Direct Debit',
    'enable_alipay' => 'Accept Alipay',
    'enable_sofort' => 'Accept EU bank transfers',
    'stripe_alipay_help' => 'These gateways also need to be activated in :link.',
    'calendar' => 'Calendar',
    'pro_plan_calendar' => ':link to enable the calendar by joining the Pro Plan',

    'what_are_you_working_on' => 'What are you working on?',
    'time_tracker' => 'Time Tracker',
    'refresh' => 'Refresh',
    'filter_sort' => 'Filter/Sort',
    'no_description' => 'No Description',
    'time_tracker_login' => 'Time Tracker Login',
    'save_or_discard' => 'Save or discard your changes',
    'discard_changes' => 'Discard Changes',
    'tasks_not_enabled' => 'Tasks are not enabled.',
    'started_task' => 'Successfully started task',
    'create_client' => 'Create Client',

    'download_desktop_app' => 'Download the desktop app',
    'download_iphone_app' => 'Download the iPhone app',
    'download_android_app' => 'Download the Android app',
    'time_tracker_mobile_help' => 'Double tap a task to select it',
    'stopped' => 'Stopped',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
    'sort_field' => 'Sort By',
    'sort_direction' => 'Direction',
    'discard' => 'Discard',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'mins',
    'time_hr' => 'hr',
    'time_hrs' => 'hrs',
    'clear' => 'Clear',
    'warn_payment_gateway' => 'Note: accepting online payments requires a payment gateway, :link to add one.',
    'task_rate' => 'Task Rate',
    'task_rate_help' => 'Set the default rate for invoiced tasks.',
    'past_due' => 'Past Due',
    'document' => 'Document',
    'invoice_or_expense' => 'Invoice/Expense',
    'invoice_pdfs' => 'Invoice PDFs',
    'enable_sepa' => 'Accept SEPA',
    'enable_bitcoin' => 'Accept Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'By providing your IBAN and confirming this payment, you are authorizing :company and Stripe, our payment service provider, to send instructions to your bank to debit your account and your bank to debit your account in accordance with those instructions. You are entitled to a refund from your bank under the terms and conditions of your agreement with your bank. A refund must be claimed within 8 weeks starting from the date on which your account was debited.',
    'recover_license' => 'Recover License',
    'purchase' => 'Purchase',
    'recover' => 'Recover',
    'apply' => 'Apply',
    'recover_white_label_header' => 'Gendan hvidmærke-licens',
    'apply_white_label_header' => 'Anvend hvidmærke-licens',
    'videos' => 'Videos',
    'video' => 'Video',
    'return_to_invoice' => 'Return to Invoice',
    'gateway_help_13' => 'To use ITN leave the PDT Key field blank.',
    'partial_due_date' => 'Partial Due Date',
    'task_fields' => 'Task Fields',
    'product_fields_help' => 'Drag and drop fields to change their order',
    'custom_value1' => 'Custom Value',
    'custom_value2' => 'Custom Value',
    'enable_two_factor' => 'Two-Factor Authentication',
    'enable_two_factor_help' => 'Use your phone to confirm your identity when logging in',
    'two_factor_setup' => 'Two-Factor Setup',
    'two_factor_setup_help' => 'Scan the bar code with a :link compatible app.',
    'one_time_password' => 'One Time Password',
    'set_phone_for_two_factor' => 'Set your mobile phone number as a backup to enable.',
    'enabled_two_factor' => 'Successfully enabled Two-Factor Authentication',
    'add_product' => 'Add Product',
    'email_will_be_sent_on' => 'Note: the email will be sent on :date.',
    'invoice_product' => 'Invoice Product',
    'self_host_login' => 'Self-Host Login',
    'set_self_hoat_url' => 'Self-Host URL',
    'local_storage_required' => 'Error: local storage is not available.',
    'your_password_reset_link' => 'Your Password Reset Link',
    'subdomain_taken' => 'The subdomain is already in use',
    'client_login' => 'Client log ing',
    'converted_amount' => 'Converted Amount',
    'default' => 'Default',
    'shipping_address' => 'Shipping Address',
    'bllling_address' => 'Billing Address',
    'billing_address1' => 'Billing Street',
    'billing_address2' => 'Billing Apt/Suite',
    'billing_city' => 'Billing City',
    'billing_state' => 'Billing State/Province',
    'billing_postal_code' => 'Billing Postal Code',
    'billing_country' => 'Billing Country',
    'shipping_address1' => 'Shipping Street',
    'shipping_address2' => 'Shipping Apt/Suite',
    'shipping_city' => 'Shipping City',
    'shipping_state' => 'Shipping State/Province',
    'shipping_postal_code' => 'Shipping Postal Code',
    'shipping_country' => 'Shipping Country',
    'classify' => 'Classify',
    'show_shipping_address_help' => 'Require client to provide their shipping address',
    'ship_to_billing_address' => 'Ship to billing address',
    'delivery_note' => 'Delivery Note',
    'show_tasks_in_portal' => 'Show tasks in the client portal',
    'cancel_schedule' => 'Cancel Schedule',
    'scheduled_report' => 'Scheduled Report',
    'scheduled_report_help' => 'Email the :report report as :format to :email',
    'created_scheduled_report' => 'Successfully scheduled report',
    'deleted_scheduled_report' => 'Successfully canceled scheduled report',
    'scheduled_report_attached' => 'Your scheduled :type report is attached.',
    'scheduled_report_error' => 'Failed to create schedule report',
    'invalid_one_time_password' => 'Invalid one time password',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Accept Apple Pay and Pay with Google',
    'requires_subdomain' => 'This payment type requires that a :link.',
    'subdomain_is_set' => 'subdomain is set',
    'verification_file' => 'Verification File',
    'verification_file_missing' => 'The verification file is needed to accept payments.',
    'apple_pay_domain' => 'Use <code>:domain</code> as the domain in :link.',
    'apple_pay_not_supported' => 'Sorry, Apple/Google Pay isn\'t supported by your browser',
    'optional_payment_methods' => 'Optional Payment Methods',
    'add_subscription' => 'Add Subscription',
    'target_url' => 'Target',
    'target_url_help' => 'When the selected event occurs the app will post the entity to the target URL.',
    'event' => 'Event',
    'subscription_event_1' => 'Created Client',
    'subscription_event_2' => 'Created Invoice',
    'subscription_event_3' => 'Created Quote',
    'subscription_event_4' => 'Created Payment',
    'subscription_event_5' => 'Created Vendor',
    'subscription_event_6' => 'Pristilbud blev opdateret',
    'subscription_event_7' => 'Deleted Quote',
    'subscription_event_8' => 'Faktura blev opdateret',
    'subscription_event_9' => 'Deleted Invoice',
    'subscription_event_10' => 'Klient blev opdateret',
    'subscription_event_11' => 'Deleted Client',
    'subscription_event_12' => 'Deleted Payment',
    'subscription_event_13' => 'Sælger blev opdateret',
    'subscription_event_14' => 'Deleted Vendor',
    'subscription_event_15' => 'Created Expense',
    'subscription_event_16' => 'Udgift blev opdateret',
    'subscription_event_17' => 'Deleted Expense',
    'subscription_event_18' => 'Created Task',
    'subscription_event_19' => 'Opgave blev opdateret',
    'subscription_event_20' => 'Deleted Task',
    'subscription_event_21' => 'Approved Quote',
    'subscriptions' => 'Subscriptions',
    'updated_subscription' => 'Abonnementet blev opdateret',
    'created_subscription' => 'Successfully created subscription',
    'edit_subscription' => 'Edit Subscription',
    'archive_subscription' => 'Archive Subscription',
    'archived_subscription' => 'Successfully archived subscription',
    'project_error_multiple_clients' => 'Projekter kan ikke tilhøre flere klienter',
    'invoice_project' => 'Fakturér projekt',
    'module_recurring_invoice' => 'Recurring Invoices',
    'module_credit' => 'Credits',
    'module_quote' => 'Pristilbud og projektforslag',
    'module_task' => 'Opgaver & projekter',
    'module_expense' => 'Expenses & Vendors',
    'module_ticket' => 'Sager',
    'reminders' => 'Reminders',
    'send_client_reminders' => 'Send email reminders',
    'can_view_tasks' => 'Tasks are visible in the portal',
    'is_not_sent_reminders' => 'Reminders are not sent',
    'promotion_footer' => 'Your promotion will expire soon, :link to upgrade now.',
    'unable_to_delete_primary' => 'Note: to delete this company first delete all linked companies.',
    'please_register' => 'Please register your account',
    'processing_request' => 'Processing request',
    'mcrypt_warning' => 'Warning: Mcrypt is deprecated, run :command to update your cipher.',
    'edit_times' => 'Edit Times',
    'inclusive_taxes_help' => 'Include <b>taxes in the cost</b>',
    'inclusive_taxes_notice' => 'This setting can not be changed once an invoice has been created.',
    'inclusive_taxes_warning' => 'Warning: existing invoices will need to be resaved',
    'copy_shipping' => 'Copy Shipping',
    'copy_billing' => 'Copy Billing',
    'quote_has_expired' => 'The quote has expired, please contact the merchant.',
    'empty_table_footer' => 'Viser 0 til 0 af 0',
    'do_not_trust' => 'Do not remember this device',
    'trust_for_30_days' => 'Trust for 30 days',
    'trust_forever' => 'Trust forever',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Ready to do',
    'in_progress' => 'In progress',
    'add_status' => 'Add status',
    'archive_status' => 'Archive Status',
    'new_status' => 'New Status',
    'convert_products' => 'Convert Products',
    'convert_products_help' => 'Automatically convert product prices to the client\'s currency',
    'improve_client_portal_link' => 'Set a subdomain to shorten the client portal link.',
    'budgeted_hours' => 'Budgeted Hours',
    'progress' => 'Progress',
    'view_project' => 'Vis projekt',
    'summary' => 'Summary',
    'endless_reminder' => 'Endless Reminder',
    'signature_on_invoice_help' => 'Add the following code to show your client\'s signature on the PDF.',
    'signature_on_pdf' => 'Show on PDF',
    'signature_on_pdf_help' => 'Show the client signature on the invoice/quote PDF.',
    'expired_white_label' => 'Hvidmærke-licens er udløbet',
    'return_to_login' => 'Return to Login',
    'convert_products_tip' => 'Note: add a :link named ":name" to see the exchange rate.',
    'amount_greater_than_balance' => 'The amount is greater than the invoice balance, a credit will be created with the remaining amount.',
    'custom_fields_tip' => 'Use <code>Label|Option1,Option2</code> to show a select box.',
    'client_information' => 'Client Information',
    'updated_client_details' => 'Successfully updated client details',
    'auto' => 'Auto',
    'tax_amount' => 'Tax Amount',
    'tax_paid' => 'Tax Paid',
    'none' => 'None',
    'proposal_message_button' => 'To view your proposal for :amount, click the button below.',
    'proposal' => 'Proposal',
    'proposals' => 'Projektforslag',
    'list_proposals' => 'List Proposals',
    'new_proposal' => 'Nyt projektforslag',
    'edit_proposal' => 'Rediger projektforslag',
    'archive_proposal' => 'Arkivér projektforslag',
    'delete_proposal' => 'Slet projektforslag',
    'created_proposal' => ' Projektforslaget blev oprettet',
    'updated_proposal' => ' Projektforslag blev opdateret',
    'archived_proposal' => ' Projektforslag blev arkiveret',
    'deleted_proposal' => ' Projektforslag blev arkiveret',
    'archived_proposals' => ':count projektforslag blev arkiveret',
    'deleted_proposals' => ':count projektforslag blev arkiveret',
    'restored_proposal' => 'Projektforslaget blev genskabt',
    'restore_proposal' => 'Genskab projektforslag',
    'snippet' => 'Snippet',
    'snippets' => 'Snippets',
    'proposal_snippet' => 'Snippet',
    'proposal_snippets' => 'Snippets',
    'new_proposal_snippet' => 'New Snippet',
    'edit_proposal_snippet' => 'Edit Snippet',
    'archive_proposal_snippet' => 'Archive Snippet',
    'delete_proposal_snippet' => 'Delete Snippet',
    'created_proposal_snippet' => 'Successfully created snippet',
    'updated_proposal_snippet' => 'Successfully updated snippet',
    'archived_proposal_snippet' => 'Successfully archived snippet',
    'deleted_proposal_snippet' => 'Successfully archived snippet',
    'archived_proposal_snippets' => 'Successfully archived :count snippets',
    'deleted_proposal_snippets' => 'Successfully archived :count snippets',
    'restored_proposal_snippet' => 'Successfully restored snippet',
    'restore_proposal_snippet' => 'Restore Snippet',
    'template' => 'Skabelon',
    'templates' => 'Skabeloner',
    'proposal_template' => 'Skabelon',
    'proposal_templates' => 'Skabeloner',
    'new_proposal_template' => 'Ny Skabelon',
    'edit_proposal_template' => 'Rediger Skabelon',
    'archive_proposal_template' => 'Arkiver Skabelon',
    'delete_proposal_template' => 'Slet Skabelon',
    'created_proposal_template' => 'Successfully created template',
    'updated_proposal_template' => 'Successfully updated template',
    'archived_proposal_template' => 'Successfully archived template',
    'deleted_proposal_template' => 'Successfully archived template',
    'archived_proposal_templates' => 'Successfully archived :count templates',
    'deleted_proposal_templates' => 'Successfully archived :count templates',
    'restored_proposal_template' => 'Successfully restored template',
    'restore_proposal_template' => 'Restore Template',
    'proposal_category' => 'Category',
    'proposal_categories' => 'Categories',
    'new_proposal_category' => 'New Category',
    'edit_proposal_category' => 'Edit Category',
    'archive_proposal_category' => 'Archive Category',
    'delete_proposal_category' => 'Delete Category',
    'created_proposal_category' => 'Successfully created category',
    'updated_proposal_category' => 'Successfully updated category',
    'archived_proposal_category' => 'Successfully archived category',
    'deleted_proposal_category' => 'Successfully archived category',
    'archived_proposal_categories' => 'Successfully archived :count categories',
    'deleted_proposal_categories' => 'Successfully archived :count categories',
    'restored_proposal_category' => 'Successfully restored category',
    'restore_proposal_category' => 'Restore Category',
    'delete_status' => 'Delete Status',
    'standard' => 'Standard',
    'icon' => 'Icon',
    'proposal_not_found' => 'Det ønskede projektforslag er ikke tilgængeligt',
    'create_proposal_category' => 'Create category',
    'clone_proposal_template' => 'Clone Template',
    'proposal_email' => 'E-mail til projektforslag',
    'proposal_subject' => 'Nyt projektforslag :number fra :account',
    'proposal_message' => 'For at se projektforslaget som er estimeret til :amount, så klik på linket herunder.',
    'emailed_proposal' => 'Projektforslaget er nu sendt!',
    'load_template' => 'Load Template',
    'no_assets' => 'No images, drag to upload',
    'add_image' => 'Add Image',
    'select_image' => 'Select Image',
    'upgrade_to_upload_images' => 'Upgrade to the enterprise plan to upload images',
    'delete_image' => 'Delete Image',
    'delete_image_help' => 'Warning: deleting the image will remove it from all proposals.',
    'amount_variable_help' => 'Note: the invoice $amount field will use the partial/deposit field if set otherwise it will use the invoice balance.',
    'taxes_are_included_help' => 'Note: Inclusive taxes have been enabled.',
    'taxes_are_not_included_help' => 'Note: Inclusive taxes are not enabled.',
    'change_requires_purge' => 'Changing this setting requires :link the account data.',
    'purging' => 'purging',
    'warning_local_refund' => 'The refund will be recorded in the app but will NOT be processed by the payment gateway.',
    'email_address_changed' => 'Email address has been changed',
    'email_address_changed_message' => 'The email address for your account has been changed from :old_email to :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Exporting to ZIP requires the GMP extension',
    'email_history' => 'Email History',
    'loading' => 'Loading',
    'no_messages_found' => 'No messages found',
    'processing' => 'Processing',
    'reactivate' => 'Reactivate',
    'reactivated_email' => 'The email address has been reactivated',
    'emails' => 'Emails',
    'opened' => 'Opened',
    'bounced' => 'Bounced',
    'total_sent' => 'Total Sent',
    'total_opened' => 'Total Opened',
    'total_bounced' => 'Total Bounced',
    'total_spam' => 'Total Spam',
    'platforms' => 'Platforms',
    'email_clients' => 'E-mail kunder',
    'mobile' => 'Mobile',
    'desktop' => 'Desktop',
    'webmail' => 'Webmail',
    'group' => 'Group',
    'subgroup' => 'Subgroup',
    'unset' => 'Unset',
    'received_new_payment' => 'You\'ve received a new payment!',
    'slack_webhook_help' => 'Receive payment notifications using :link.',
    'slack_incoming_webhooks' => 'Slack incoming webhooks',
    'accept' => 'Accept',
    'accepted_terms' => 'Successfully accepted the latest terms of service',
    'invalid_url' => 'Invalid URL',
    'workflow_settings' => 'Workflow Settings',
    'auto_email_invoice' => 'Auto Email',
    'auto_email_invoice_help' => 'Automatically email recurring invoices when they are created.',
    'auto_archive_invoice' => 'Auto Archive',
    'auto_archive_invoice_help' => 'Automatically archive invoices when they are paid.',
    'auto_archive_quote' => 'Auto Archive',
    'auto_archive_quote_help' => 'Automatically archive quotes when they are converted.',
    'require_approve_quote' => 'Require approve quote',
    'require_approve_quote_help' => 'Require clients to approve quotes.',
    'allow_approve_expired_quote' => 'Allow approve expired quote',
    'allow_approve_expired_quote_help' => 'Allow clients to approve expired quotes.',
    'invoice_workflow' => 'Invoice Workflow',
    'quote_workflow' => 'Quote Workflow',
    'client_must_be_active' => 'Error: the client must be active',
    'purge_client' => 'Purge Client',
    'purged_client' => 'Successfully purged client',
    'purge_client_warning' => 'All related records (invoices, tasks, expenses, documents, etc) will also be deleted.',
    'clone_product' => 'Clone Product',
    'item_details' => 'Item Details',
    'send_item_details_help' => 'Send line item details to the payment gateway.',
    'view_proposal' => 'Se projektforslag',
    'view_in_portal' => 'View in Portal',
    'cookie_message' => 'This website uses cookies to ensure you get the best experience on our website.',
    'got_it' => 'Got it!',
    'vendor_will_create' => 'vendor will be created',
    'vendors_will_create' => 'vendors will be created',
    'created_vendors' => 'Successfully created :count vendor(s)',
    'import_vendors' => 'Import Vendors',
    'company' => 'Company',
    'client_field' => 'Client Field',
    'contact_field' => 'Contact Field',
    'product_field' => 'Product Field',
    'task_field' => 'Task Field',
    'project_field' => 'Projektfelt',
    'expense_field' => 'Expense Field',
    'vendor_field' => 'Vendor Field',
    'company_field' => 'Company Field',
    'invoice_field' => 'Invoice Field',
    'invoice_surcharge' => 'Invoice Surcharge',
    'custom_task_fields_help' => 'Add a field when creating a task.',
    'custom_project_fields_help' => 'Tilføj et felt når der oprettes et projekt',
    'custom_expense_fields_help' => 'Add a field when creating an expense.',
    'custom_vendor_fields_help' => 'Add a field when creating a vendor.',
    'messages' => 'Messages',
    'unpaid_invoice' => 'Unpaid Invoice',
    'paid_invoice' => 'Paid Invoice',
    'unapproved_quote' => 'Unapproved Quote',
    'unapproved_proposal' => 'Ikke-godkendte projektforslag',
    'autofills_city_state' => 'Auto-fills city/state',
    'no_match_found' => 'No match found',
    'password_strength' => 'Password Strength',
    'strength_weak' => 'Weak',
    'strength_good' => 'Good',
    'strength_strong' => 'Strong',
    'mark' => 'Mark',
    'updated_task_status' => 'Successfully update task status',
    'background_image' => 'Background Image',
    'background_image_help' => 'Use the :link to manage your images, we recommend using a small file.',
    'proposal_editor' => 'proposal editor',
    'background' => 'Background',
    'guide' => 'Guide',
    'gateway_fee_item' => 'Gateway Fee Item',
    'gateway_fee_description' => 'Gateway Fee Surcharge',
    'gateway_fee_discount_description' => 'Gateway Fee Discount',
    'show_payments' => 'Show Payments',
    'show_aging' => 'Show Aging',
    'reference' => 'Reference',
    'amount_paid' => 'Amount Paid',
    'send_notifications_for' => 'Send Notifications For',
    'all_invoices' => 'All Invoices',
    'my_invoices' => 'My Invoices',
    'payment_reference' => 'Payment Reference',
    'maximum' => 'Maximum',
    'sort' => 'Sort',
    'refresh_complete' => 'Refresh Complete',
    'please_enter_your_email' => 'Please enter your email',
    'please_enter_your_password' => 'Please enter your password',
    'please_enter_your_url' => 'Please enter your URL',
    'please_enter_a_product_key' => 'Please enter a product key',
    'an_error_occurred' => 'An error occurred',
    'overview' => 'Overview',
    'copied_to_clipboard' => 'Copied :value to the clipboard',
    'error' => 'Error',
    'could_not_launch' => 'Could not launch',
    'additional' => 'Additional',
    'ok' => 'Ok',
    'email_is_invalid' => 'Email is invalid',
    'items' => 'Items',
    'partial_deposit' => 'Partial/Deposit',
    'add_item' => 'Add Item',
    'total_amount' => 'Total Amount',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Invoice Status',
    'click_plus_to_add_item' => 'Click + to add an item',
    'count_selected' => ':count selected',
    'dismiss' => 'Dismiss',
    'please_select_a_date' => 'Please select a date',
    'please_select_a_client' => 'Please select a client',
    'language' => 'Language',
    'updated_at' => 'Opdateret',
    'please_enter_an_invoice_number' => 'Please enter an invoice number',
    'please_enter_a_quote_number' => 'Please enter a quote number',
    'clients_invoices' => ':client\'s invoices',
    'viewed' => 'Viewed',
    'approved' => 'Approved',
    'invoice_status_1' => 'Draft',
    'invoice_status_2' => 'Sent',
    'invoice_status_3' => 'Viewed',
    'invoice_status_4' => 'Approved',
    'invoice_status_5' => 'Partial',
    'invoice_status_6' => 'Betalt',
    'marked_invoice_as_sent' => 'Successfully marked invoice as sent',
    'please_enter_a_client_or_contact_name' => 'Please enter a client or contact name',
    'restart_app_to_apply_change' => 'Restart the app to apply the change',
    'refresh_data' => 'Refresh Data',
    'blank_contact' => 'Blank Contact',
    'no_records_found' => 'No records found',
    'industry' => 'Industry',
    'size' => 'Size',
    'net' => 'Net',
    'show_tasks' => 'Show tasks',
    'email_reminders' => 'Email Reminders',
    'reminder1' => 'First Reminder',
    'reminder2' => 'Second Reminder',
    'reminder3' => 'Third Reminder',
    'send' => 'Send',
    'auto_billing' => 'Auto billing',
    'button' => 'Button',
    'more' => 'More',
    'edit_recurring_invoice' => 'Edit Recurring Invoice',
    'edit_recurring_quote' => 'Edit Recurring Quote',
    'quote_status' => 'Quote Status',
    'please_select_an_invoice' => 'Please select an invoice',
    'filtered_by' => 'Filtered by',
    'payment_status' => 'Payment Status',
    'payment_status_1' => 'Pending',
    'payment_status_2' => 'Voided',
    'payment_status_3' => 'Failed',
    'payment_status_4' => 'Completed',
    'payment_status_5' => 'Partially Refunded',
    'payment_status_6' => 'Refunded',
    'send_receipt_to_client' => 'Send receipt to the client',
    'refunded' => 'Refunded',
    'marked_quote_as_sent' => 'Successfully marked quote as sent',
    'custom_module_settings' => 'Custom Module Settings',
    'ticket' => 'Sag',
    'tickets' => 'Sager',
    'ticket_number' => 'Sag #',
    'new_ticket' => 'Ny sag',
    'edit_ticket' => 'Redigér sag',
    'view_ticket' => 'Vis sag',
    'archive_ticket' => 'Arkivér sag',
    'restore_ticket' => 'Genskab sag',
    'delete_ticket' => 'Slet sag',
    'archived_ticket' => 'Sag blev arkiveret',
    'archived_tickets' => 'Sager blev arkiveret',
    'restored_ticket' => 'Sag blev genskabt',
    'deleted_ticket' => 'Sag blev slettet',
    'open' => 'Open',
    'new' => 'New',
    'closed' => 'Closed',
    'reopened' => 'Reopened',
    'priority' => 'Priority',
    'last_updated' => 'Senest opdateret',
    'comment' => 'Comments',
    'tags' => 'Tags',
    'linked_objects' => 'Linked Objects',
    'low' => 'Low',
    'medium' => 'Medium',
    'high' => 'High',
    'no_due_date' => 'Ingen forfaldsdato angivet',
    'assigned_to' => 'Assigned to',
    'reply' => 'Reply',
    'awaiting_reply' => 'Awaiting reply',
    'ticket_close' => 'Luk sag',
    'ticket_reopen' => 'Genåbn sag',
    'ticket_open' => 'Åbn sag',
    'ticket_split' => 'Opdel sag',
    'ticket_merge' => 'Sammenflet sag',
    'ticket_update' => 'Opdatér sag',
    'ticket_settings' => 'Sagsindstillinger',
    'updated_ticket' => 'Sag blev opdateret',
    'mark_spam' => 'Mark as Spam',
    'local_part' => 'Local Part',
    'local_part_unavailable' => 'Name taken',
    'local_part_available' => 'Name available',
    'local_part_invalid' => 'Invalid name (alpha numeric only, no spaces',
    'local_part_help' => 'Customize the local part of your inbound support email, ie. YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => 'From name is the recognizable sender which is displayed instead of the email address, ie Support Center',
    'local_part_placeholder' => 'YOUR_NAME',
    'from_name_placeholder' => 'Support Center',
    'attachments' => 'Attachments',
    'client_upload' => 'Client uploads',
    'enable_client_upload_help' => 'Allow clients to upload documents/attachments',
    'max_file_size_help' => 'Maximum file size (KB) is limited by your post_max_size and upload_max_filesize variables as set in your PHP.INI',
    'max_file_size' => 'Maximum file size',
    'mime_types' => 'Mime types',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Comma separated list of allowed mime types, leave blank for all',
    'ticket_number_start_help' => 'Sagsnummer skal være større end det nuværende sagsnummer',
    'new_ticket_template_id' => 'Ny sag',
    'new_ticket_autoresponder_help' => 'Valg af en skabelon vil sende et auto-svar til en klient/kontakt når en ny sag oprettes',
    'update_ticket_template_id' => 'Sag blev opdateret',
    'update_ticket_autoresponder_help' => 'Valg af en skabelon vil sende et auto-svar til en klient/kontakt når en sag bliver opdateret',
    'close_ticket_template_id' => 'Sag blev lukket',
    'close_ticket_autoresponder_help' => 'Valg af en skabelon vil sende et auto-svar til en klient/kontakt når en sag lukkes',
    'default_priority' => 'Default priority',
    'alert_new_comment_id' => 'New comment',
    'alert_comment_ticket_help' => 'Selecting a template will send a notification (to agent) when a comment is made.',
    'alert_comment_ticket_email_help' => 'Comma separated emails to bcc on new comment.',
    'new_ticket_notification_list' => 'Additional new ticket notifications',
    'update_ticket_notification_list' => 'Additional new comment notifications',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Tildeling af sag',
    'alert_ticket_assign_agent_id_hel' => 'Selecting a template will send a notification (to agent) when a ticket is assigned.',
    'alert_ticket_assign_agent_id_notifications' => 'Additional ticket assigned notifications',
    'alert_ticket_assign_agent_id_help' => 'Comma separated emails to bcc on ticket assignment.',
    'alert_ticket_transfer_email_help' => 'Comma separated emails to bcc on ticket transfer.',
    'alert_ticket_overdue_agent_id' => 'Sag er forfalden',
    'alert_ticket_overdue_email' => 'Additional overdue ticket notifications',
    'alert_ticket_overdue_email_help' => 'Comma separated emails to bcc on ticket overdue.',
    'alert_ticket_overdue_agent_id_help' => 'Selecting a template will send a notification (to agent) when a ticket becomes overdue.',
    'ticket_master' => 'Ticket Master',
    'ticket_master_help' => 'Has the ability to assign and transfer tickets. Assigned as the default agent for all tickets.',
    'default_agent' => 'Default Agent',
    'default_agent_help' => 'If selected will automatically be assigned to all inbound tickets',
    'show_agent_details' => 'Show agent details on responses',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Remove avatar',
    'ticket_not_found' => 'Sag blev ikke fundet',
    'add_template' => 'Add Template',
    'ticket_template' => 'Sagsskabelon',
    'ticket_templates' => 'Sagsskabeloner',
    'updated_ticket_template' => 'Sagsskabelon blev opdateret',
    'created_ticket_template' => 'Sagsskabelon blev oprettet',
    'archive_ticket_template' => 'Archive Template',
    'restore_ticket_template' => 'Restore Template',
    'archived_ticket_template' => 'Successfully archived template',
    'restored_ticket_template' => 'Successfully restored template',
    'close_reason' => 'Fortæl os hvorfor du lukker denne sag',
    'reopen_reason' => 'Fortæl os hvorfor du genåbner denne sag',
    'enter_ticket_message' => 'Skriv venligst en besked for at opdatere denne sag',
    'show_hide_all' => 'Show / Hide all',
    'subject_required' => 'Subject required',
    'mobile_refresh_warning' => 'If you\'re using the mobile app you may need to do a full refresh.',
    'enable_proposals_for_background' => 'To upload a background image :link to enable the proposals module.',
    'ticket_assignment' => 'Sag :ticket_number er blevet tildelt til :agent',
    'ticket_contact_reply' => 'Sag :ticket_number er blevet opdateret af klienten :contact',
    'ticket_new_template_subject' => 'Sag :ticket_number blev oprettet',
    'ticket_updated_template_subject' => 'Sag :ticket_number er blevet opdateret',
    'ticket_closed_template_subject' => 'Sag :ticket_number er blevet lukket.',
    'ticket_overdue_template_subject' => 'Sag :ticket_number er nu forfalden',
    'merge' => 'Merge',
    'merged' => 'Merged',
    'agent' => 'Agent',
    'parent_ticket' => 'Overordnet sag',
    'linked_tickets' => 'Sammenkædede sager',
    'merge_prompt' => 'Angiv dét sagsnummer som der skal flettes ind i',
    'merge_from_to' => 'Sagen #:old_ticket blev flettet ind i sag #:new_ticket',
    'merge_closed_ticket_text' => 'Sagen #:old_ticket blev lukket og flettet ind i sag#:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Sagen #:old_ticket blev lukket og flettet ind i denne sag',
    'merge_placeholder' => 'Sammenflet sagen #:ticket ind i følgende sag',
    'select_ticket' => 'Vælg sag',
    'new_internal_ticket' => 'Ny intern sag',
    'internal_ticket' => 'Intern sag',
    'create_ticket' => 'Opret sag',
    'allow_inbound_email_tickets_external' => 'Nye sager per e-mail (klient)',
    'allow_inbound_email_tickets_external_help' => 'Tillad at klienter opretter nye sager per e-mail',
    'include_in_filter' => 'Include in filter',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Compare',
    'hosted_login' => 'Hosted Login',
    'selfhost_login' => 'Selfhost Login',
    'google_login' => 'Google Login',
    'thanks_for_patience' => 'Thank for your patience while we work to implement these features.\n\nWe hope to have them completed in the next few months.\n\nUntil then we\'ll continue to support the',
    'legacy_mobile_app' => 'legacy mobile app',
    'today' => 'Today',
    'current' => 'Current',
    'previous' => 'Previous',
    'current_period' => 'Current Period',
    'comparison_period' => 'Comparison Period',
    'previous_period' => 'Previous Period',
    'previous_year' => 'Previous Year',
    'compare_to' => 'Compare to',
    'last_week' => 'Last Week',
    'clone_to_invoice' => 'Clone to Invoice',
    'clone_to_quote' => 'Clone to Quote',
    'convert' => 'Convert',
    'last7_days' => 'Last 7 Days',
    'last30_days' => 'Last 30 Days',
    'custom_js' => 'Custom JS',
    'adjust_fee_percent_help' => 'Adjust percent to account for fee',
    'show_product_notes' => 'Show product details',
    'show_product_notes_help' => 'Include the <b>description and cost</b> in the product dropdown',
    'important' => 'Important',
    'thank_you_for_using_our_app' => 'Thank you for using our app!',
    'if_you_like_it' => 'If you like it please',
    'to_rate_it' => 'to rate it.',
    'average' => 'Average',
    'unapproved' => 'Unapproved',
    'authenticate_to_change_setting' => 'Please authenticate to change this setting',
    'locked' => 'Locked',
    'authenticate' => 'Authenticate',
    'please_authenticate' => 'Please authenticate',
    'biometric_authentication' => 'Biometric Authentication',
    'auto_start_tasks' => 'Auto Start Tasks',
    'budgeted' => 'Budgeted',
    'please_enter_a_name' => 'Please enter a name',
    'click_plus_to_add_time' => 'Click + to add time',
    'design' => 'Design',
    'password_is_too_short' => 'Password is too short',
    'failed_to_find_record' => 'Failed to find record',
    'valid_until_days' => 'Valid Until',
    'valid_until_days_help' => 'Automatically sets the <b>Valid Until</b> value on quotes to this many days in the future.  Leave blank to disable.',
    'usually_pays_in_days' => 'Days',
    'requires_an_enterprise_plan' => 'Requires an enterprise plan',
    'take_picture' => 'Take Picture',
    'upload_file' => 'Upload File',
    'new_document' => 'New Document',
    'edit_document' => 'Edit Document',
    'uploaded_document' => 'Successfully uploaded document',
    'updated_document' => 'Successfully updated document',
    'archived_document' => 'Successfully archived document',
    'deleted_document' => 'Successfully deleted document',
    'restored_document' => 'Successfully restored document',
    'no_history' => 'No History',
    'expense_status_1' => 'Logged',
    'expense_status_2' => 'Pending',
    'expense_status_3' => 'Invoiced',
    'no_record_selected' => 'No record selected',
    'error_unsaved_changes' => 'Please save or cancel your changes',
    'thank_you_for_your_purchase' => 'Thank you for your purchase!',
    'redeem' => 'Redeem',
    'back' => 'Back',
    'past_purchases' => 'Past Purchases',
    'annual_subscription' => 'Annual Subscription',
    'pro_plan' => 'Pro Plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count users',
    'upgrade' => 'Upgrade',
    'please_enter_a_first_name' => 'Please enter a first name',
    'please_enter_a_last_name' => 'Please enter a last name',
    'please_agree_to_terms_and_privacy' => 'Please agree to the terms of service and privacy policy to create an account.',
    'i_agree_to_the' => 'I agree to the',
    'terms_of_service_link' => 'terms of service',
    'privacy_policy_link' => 'privacy policy',
    'view_website' => 'View Website',
    'create_account' => 'Create Account',
    'email_login' => 'Email Login',
    'late_fees' => 'Late Fees',
    'payment_number' => 'Payment Number',
    'before_due_date' => 'Before the due date',
    'after_due_date' => 'After the due date',
    'after_invoice_date' => 'After the invoice date',
    'filtered_by_user' => 'Filtered by User',
    'created_user' => 'Successfully created user',
    'primary_font' => 'Primary Font',
    'secondary_font' => 'Secondary Font',
    'number_padding' => 'Number Padding',
    'general' => 'General',
    'surcharge_field' => 'Surcharge Field',
    'company_value' => 'Company Value',
    'credit_field' => 'Credit Field',
    'payment_field' => 'Payment Field',
    'group_field' => 'Group Field',
    'number_counter' => 'Number Counter',
    'number_pattern' => 'Number Pattern',
    'custom_javascript' => 'Custom JavaScript',
    'portal_mode' => 'Portal Mode',
    'attach_pdf' => 'Attach PDF',
    'attach_documents' => 'Attach Documents',
    'attach_ubl' => 'Attach UBL',
    'email_style' => 'Email Style',
    'processed' => 'Processed',
    'fee_amount' => 'Fee Amount',
    'fee_percent' => 'Fee Percent',
    'fee_cap' => 'Fee Cap',
    'limits_and_fees' => 'Limits/Fees',
    'credentials' => 'Credentials',
    'require_billing_address_help' => 'Require client to provide their billing address',
    'require_shipping_address_help' => 'Require client to provide their shipping address',
    'deleted_tax_rate' => 'Successfully deleted tax rate',
    'restored_tax_rate' => 'Successfully restored tax rate',
    'provider' => 'Provider',
    'company_gateway' => 'Payment Gateway',
    'company_gateways' => 'Payment Gateways',
    'new_company_gateway' => 'New Gateway',
    'edit_company_gateway' => 'Edit Gateway',
    'created_company_gateway' => 'Successfully created gateway',
    'updated_company_gateway' => 'Successfully updated gateway',
    'archived_company_gateway' => 'Successfully archived gateway',
    'deleted_company_gateway' => 'Successfully deleted gateway',
    'restored_company_gateway' => 'Successfully restored gateway',
    'continue_editing' => 'Continue Editing',
    'default_value' => 'Default value',
    'currency_format' => 'Currency Format',
    'first_day_of_the_week' => 'First Day of the Week',
    'first_month_of_the_year' => 'First Month of the Year',
    'symbol' => 'Symbol',
    'ocde' => 'Code',
    'date_format' => 'Date Format',
    'datetime_format' => 'Datetime Format',
    'send_reminders' => 'Send Reminders',
    'timezone' => 'Timezone',
    'filtered_by_group' => 'Filtered by Group',
    'filtered_by_invoice' => 'Filtered by Invoice',
    'filtered_by_client' => 'Filtered by Client',
    'filtered_by_vendor' => 'Filtered by Vendor',
    'group_settings' => 'Group Settings',
    'groups' => 'Groups',
    'new_group' => 'New Group',
    'edit_group' => 'Edit Group',
    'created_group' => 'Successfully created group',
    'updated_group' => 'Successfully updated group',
    'archived_group' => 'Successfully archived group',
    'deleted_group' => 'Successfully deleted group',
    'restored_group' => 'Successfully restored group',
    'upload_logo' => 'Upload Logo',
    'uploaded_logo' => 'Successfully uploaded logo',
    'saved_settings' => 'Successfully saved settings',
    'device_settings' => 'Device Settings',
    'credit_cards_and_banks' => 'Credit Cards & Banks',
    'price' => 'Price',
    'email_sign_up' => 'Email Sign Up',
    'google_sign_up' => 'Google Sign Up',
    'sign_up_with_google' => 'Sign Up With Google',
    'long_press_multiselect' => 'Long-press Multiselect',
    'migrate_to_next_version' => 'Migrate to the next version of Invoice Ninja',
    'migrate_intro_text' => 'We\'ve been working on next version of Invoice Ninja. Click the button bellow to start the migration.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'Welcome to the new version of Invoice Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Press button below to download the data.',
    'migration_import' => 'Awesome! Now you are ready to import your migration. Go to your new installation to import your data',
    'continue' => 'Continue',
    'company1' => 'Custom Company 1',
    'company2' => 'Custom Company 2',
    'company3' => 'Custom Company 3',
    'company4' => 'Custom Company 4',
    'product1' => 'Custom Product 1',
    'product2' => 'Custom Product 2',
    'product3' => 'Custom Product 3',
    'product4' => 'Custom Product 4',
    'client1' => 'Custom Client 1',
    'client2' => 'Custom Client 2',
    'client3' => 'Custom Client 3',
    'client4' => 'Custom Client 4',
    'contact1' => 'Custom Contact 1',
    'contact2' => 'Custom Contact 2',
    'contact3' => 'Custom Contact 3',
    'contact4' => 'Custom Contact 4',
    'task1' => 'Custom Task 1',
    'task2' => 'Custom Task 2',
    'task3' => 'Custom Task 3',
    'task4' => 'Custom Task 4',
    'project1' => 'Custom Project 1',
    'project2' => 'Custom Project 2',
    'project3' => 'Custom Project 3',
    'project4' => 'Custom Project 4',
    'expense1' => 'Custom Expense 1',
    'expense2' => 'Custom Expense 2',
    'expense3' => 'Custom Expense 3',
    'expense4' => 'Custom Expense 4',
    'vendor1' => 'Custom Vendor 1',
    'vendor2' => 'Custom Vendor 2',
    'vendor3' => 'Custom Vendor 3',
    'vendor4' => 'Custom Vendor 4',
    'invoice1' => 'Custom Invoice 1',
    'invoice2' => 'Custom Invoice 2',
    'invoice3' => 'Custom Invoice 3',
    'invoice4' => 'Custom Invoice 4',
    'payment1' => 'Custom Payment 1',
    'payment2' => 'Custom Payment 2',
    'payment3' => 'Custom Payment 3',
    'payment4' => 'Custom Payment 4',
    'surcharge1' => 'Custom Surcharge 1',
    'surcharge2' => 'Custom Surcharge 2',
    'surcharge3' => 'Custom Surcharge 3',
    'surcharge4' => 'Custom Surcharge 4',
    'group1' => 'Custom Group 1',
    'group2' => 'Custom Group 2',
    'group3' => 'Custom Group 3',
    'group4' => 'Custom Group 4',
    'number' => 'Number',
    'count' => 'Count',
    'is_active' => 'Is Active',
    'contact_last_login' => 'Contact Last Login',
    'contact_full_name' => 'Contact Full Name',
    'contact_custom_value1' => 'Contact Custom Value 1',
    'contact_custom_value2' => 'Contact Custom Value 2',
    'contact_custom_value3' => 'Contact Custom Value 3',
    'contact_custom_value4' => 'Contact Custom Value 4',
    'assigned_to_id' => 'Assigned To Id',
    'created_by_id' => 'Created By Id',
    'add_column' => 'Add Column',
    'edit_columns' => 'Edit Columns',
    'to_learn_about_gogle_fonts' => 'to learn about Google Fonts',
    'refund_date' => 'Refund Date',
    'multiselect' => 'Multiselect',
    'verify_password' => 'Verify Password',
    'applied' => 'Applied',
    'include_recent_errors' => 'Include recent errors from the logs',
    'your_message_has_been_received' => 'We have received your message and will try to respond promptly.',
    'show_product_details' => 'Show Product Details',
    'show_product_details_help' => 'Include the description and cost in the product dropdown',
    'pdf_min_requirements' => 'The PDF renderer requires :version',
    'adjust_fee_percent' => 'Adjust Fee Percent',
    'configure_settings' => 'Configure Settings',
    'about' => 'About',
    'credit_email' => 'Credit Email',
    'domain_url' => 'Domain URL',
    'password_is_too_easy' => 'Password must contain an upper case character and a number',
    'client_portal_tasks' => 'Client Portal Tasks',
    'client_portal_dashboard' => 'Client Portal Dashboard',
    'please_enter_a_value' => 'Please enter a value',
    'deleted_logo' => 'Successfully deleted logo',
    'generate_number' => 'Generate Number',
    'when_saved' => 'When Saved',
    'when_sent' => 'When Sent',
    'select_company' => 'Select Company',
    'float' => 'Float',
    'collapse' => 'Collapse',
    'show_or_hide' => 'Show/hide',
    'menu_sidebar' => 'Menu Sidebar',
    'history_sidebar' => 'History Sidebar',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Module',
    'first_custom' => 'First Custom',
    'second_custom' => 'Second Custom',
    'third_custom' => 'Third Custom',
    'show_cost' => 'Show Cost',
    'show_cost_help' => 'Display a product cost field to track the markup/profit',
    'show_product_quantity' => 'Show Product Quantity',
    'show_product_quantity_help' => 'Display a product quantity field, otherwise default to one',
    'show_invoice_quantity' => 'Show Invoice Quantity',
    'show_invoice_quantity_help' => 'Display a line item quantity field, otherwise default to one',
    'default_quantity' => 'Default Quantity',
    'default_quantity_help' => 'Automatically set the line item quantity to one',
    'one_tax_rate' => 'One Tax Rate',
    'two_tax_rates' => 'Two Tax Rates',
    'three_tax_rates' => 'Three Tax Rates',
    'default_tax_rate' => 'Default Tax Rate',
    'invoice_tax' => 'Invoice Tax',
    'line_item_tax' => 'Line Item Tax',
    'inclusive_taxes' => 'Inclusive Taxes',
    'invoice_tax_rates' => 'Invoice Tax Rates',
    'item_tax_rates' => 'Item Tax Rates',
    'configure_rates' => 'Configure rates',
    'tax_settings_rates' => 'Tax Rates',
    'accent_color' => 'Accent Color',
    'comma_sparated_list' => 'Comma separated list',
    'single_line_text' => 'Single-line text',
    'multi_line_text' => 'Multi-line text',
    'dropdown' => 'Dropdown',
    'field_type' => 'Field Type',
    'recover_password_email_sent' => 'A password recovery email has been sent',
    'removed_user' => 'Successfully removed user',
    'freq_three_years' => 'Three Years',
    'military_time_help' => '24 Hour Display',
    'click_here_capital' => 'Click here',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Successfully marked invoices as sent',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'System failed to email invoice :invoice',
    'custom_value3' => 'Custom Value 3',
    'custom_value4' => 'Custom Value 4',
    'email_style_custom' => 'Custom Email Style',
    'custom_message_dashboard' => 'Custom Dashboard Message',
    'custom_message_unpaid_invoice' => 'Custom Unpaid Invoice Message',
    'custom_message_paid_invoice' => 'Custom Paid Invoice Message',
    'custom_message_unapproved_quote' => 'Custom Unapproved Quote Message',
    'lock_sent_invoices' => 'Lock Sent Invoices',
    'translations' => 'Translations',
    'task_number_pattern' => 'Task Number Pattern',
    'task_number_counter' => 'Task Number Counter',
    'expense_number_pattern' => 'Expense Number Pattern',
    'expense_number_counter' => 'Expense Number Counter',
    'vendor_number_pattern' => 'Vendor Number Pattern',
    'vendor_number_counter' => 'Vendor Number Counter',
    'ticket_number_pattern' => 'Ticket Number Pattern',
    'ticket_number_counter' => 'Ticket Number Counter',
    'payment_number_pattern' => 'Payment Number Pattern',
    'payment_number_counter' => 'Payment Number Counter',
    'invoice_number_pattern' => 'Invoice Number Pattern',
    'quote_number_pattern' => 'Quote Number Pattern',
    'client_number_pattern' => 'Credit Number Pattern',
    'client_number_counter' => 'Credit Number Counter',
    'credit_number_pattern' => 'Credit Number Pattern',
    'credit_number_counter' => 'Credit Number Counter',
    'reset_counter_date' => 'Reset Counter Date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Shared Invoice Quote Counter',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Email Invoice Subject',
    'email_subject_quote' => 'Email Quote Subject',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Client City',
    'client_state' => 'Client State',
    'client_country' => 'Client Country',
    'client_is_active' => 'Client is Active',
    'client_balance' => 'Client Balance',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Tax Rate 1',
    'tax_rate2' => 'Tax Rate 2',
    'tax_rate3' => 'Tax Rate 3',
    'archived_at' => 'Archived At',
    'has_expenses' => 'Has Expenses',
    'custom_taxes1' => 'Custom Taxes 1',
    'custom_taxes2' => 'Custom Taxes 2',
    'custom_taxes3' => 'Custom Taxes 3',
    'custom_taxes4' => 'Custom Taxes 4',
    'custom_surcharge1' => 'Custom Surcharge 1',
    'custom_surcharge2' => 'Custom Surcharge 2',
    'custom_surcharge3' => 'Custom Surcharge 3',
    'custom_surcharge4' => 'Custom Surcharge 4',
    'is_deleted' => 'Is Deleted',
    'vendor_city' => 'Vendor City',
    'vendor_state' => 'Vendor State',
    'vendor_country' => 'Vendor Country',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Credit Terms',
    'untitled_company' => 'Untitled Company',
    'added_company' => 'Successfully added company',
    'supported_events' => 'Supported Events',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Optional',
    'license' => 'License',
    'invoice_balance' => 'Invoice Balance',
    'saved_design' => 'Successfully saved design',
    'client_details' => 'Client Details',
    'company_address' => 'Company Address',
    'quote_details' => 'Quote Details',
    'credit_details' => 'Credit Details',
    'product_columns' => 'Product Columns',
    'task_columns' => 'Task Columns',
    'add_field' => 'Add Field',
    'all_events' => 'All Events',
    'owned' => 'Owned',
    'payment_success' => 'Payment Success',
    'payment_failure' => 'Payment Failure',
    'quote_sent' => 'Quote Sent',
    'credit_sent' => 'Credit Sent',
    'invoice_viewed' => 'Invoice Viewed',
    'quote_viewed' => 'Quote Viewed',
    'credit_viewed' => 'Credit Viewed',
    'quote_approved' => 'Quote Approved',
    'receive_all_notifications' => 'Receive All Notifications',
    'purchase_license' => 'Purchase License',
    'enable_modules' => 'Enable Modules',
    'converted_quote' => 'Successfully converted quote',
    'credit_design' => 'Credit Design',
    'includes' => 'Includes',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Custom Designs',
    'designs' => 'Designs',
    'new_design' => 'New Design',
    'edit_design' => 'Edit Design',
    'created_design' => 'Successfully created design',
    'updated_design' => 'Successfully updated design',
    'archived_design' => 'Successfully archived design',
    'deleted_design' => 'Successfully deleted design',
    'removed_design' => 'Successfully removed design',
    'restored_design' => 'Successfully restored design',
    'recurring_tasks' => 'Recurring Tasks',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Latest Version',
    'update_now' => 'Update Now',
    'a_new_version_is_available' => 'A new version of the web app is available',
    'update_available' => 'Update Available',
    'app_updated' => 'Update successfully completed',
    'integrations' => 'Integrations',
    'tracking_id' => 'Tracking Id',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Partial Payment',
    'partial_payment_email' => 'Partial Payment Email',
    'clone_to_credit' => 'Clone to Credit',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Email Partial Payment Subject',
    'is_approved' => 'Is Approved',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Client does not have an email address set',
    'ledger' => 'Ledger',
    'view_pdf' => 'View PDF',
    'all_records' => 'All records',
    'owned_by_user' => 'Owned by user',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configure Payment Terms',
    'payment_term' => 'Payment Term',
    'new_payment_term' => 'New Payment Term',
    'deleted_payment_term' => 'Successfully deleted payment term',
    'removed_payment_term' => 'Successfully removed payment term',
    'restored_payment_term' => 'Successfully restored payment term',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Sign in with email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Quote Amount',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Hide Menu',
    'show_menu' => 'Show Menu',
    'partially_refunded' => 'Partially Refunded',
    'search_documents' => 'Search Documents',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Search Invoices',
    'search_clients' => 'Search Clients',
    'search_products' => 'Search Products',
    'search_quotes' => 'Search Quotes',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Search Vendors',
    'search_users' => 'Search Users',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Search Tasks',
    'search_settings' => 'Search Settings',
    'search_projects' => 'Search Projects',
    'search_expenses' => 'Search Expenses',
    'search_payments' => 'Search Payments',
    'search_groups' => 'Search Groups',
    'search_company' => 'Search Company',
    'cancelled_invoice' => 'Successfully cancelled invoice',
    'cancelled_invoices' => 'Successfully cancelled invoices',
    'reversed_invoice' => 'Successfully reversed invoice',
    'reversed_invoices' => 'Successfully reversed invoices',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Sign in with Google',
    'activity_58' => ':user reversed invoice :invoice',
    'activity_59' => ':user cancelled invoice :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'System Logs',
    'copy_link' => 'Copy Link',
    'welcome_to_invoice_ninja' => 'Welcome to Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Page :current of :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Rows Per Page',
    'apply_payment' => 'Apply Payment',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Custom Labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Height',
    'width' => 'Width',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Company Key',
    'storefront' => 'Storefront',
    'storefront_help' => 'Enable third-party apps to create invoices',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Client Created',
    'online_payment_email' => 'Online Payment Email',
    'manual_payment_email' => 'Manual Payment Email',
    'completed' => 'Completed',
    'gross' => 'Gross',
    'net_amount' => 'Net Amount',
    'net_balance' => 'Net Balance',
    'client_settings' => 'Client Settings',
    'selected_invoices' => 'Selected Invoices',
    'selected_payments' => 'Selected Payments',
    'selected_quotes' => 'Selected Quotes',
    'selected_tasks' => 'Selected Tasks',
    'selected_expenses' => 'Selected Expenses',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Update Quote',
    'update_invoice' => 'Update Invoice',
    'update_client' => 'Update Client',
    'update_vendor' => 'Update Vendor',
    'create_expense' => 'Create Expense',
    'update_expense' => 'Update Expense',
    'update_task' => 'Update Task',
    'approve_quote' => 'Approve Quote',
    'when_paid' => 'When Paid',
    'expires_on' => 'Expires On',
    'show_sidebar' => 'Show Sidebar',
    'hide_sidebar' => 'Hide Sidebar',
    'event_type' => 'Event Type',
    'copy' => 'Copy',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Client Registration',
    'client_registration_help' => 'Enable clients to self register in the portal',
    'customize_and_preview' => 'Customize & Preview',
    'search_document' => 'Search 1 Document',
    'search_design' => 'Search 1 Design',
    'search_invoice' => 'Search 1 Invoice',
    'search_client' => 'Search 1 Client',
    'search_product' => 'Search 1 Product',
    'search_quote' => 'Search 1 Quote',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Search 1 Vendor',
    'search_user' => 'Search 1 User',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Search 1 Tasks',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Search 1 Payment',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Created On',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Lock Invoices',
    'show_table' => 'Show Table',
    'show_list' => 'Show List',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
